@@ -21,6 +21,7 @@
 
 #include <gtkmm/table.h>
 
+#include "lifeobase.hpp"
 #include "dialog_export.hpp"
 #include "dialog_password.hpp"
 
@@ -28,20 +29,73 @@ using namespace LIFEO;
 
 // DIALOGSAVEDIARY =================================================================================
 DialogSaveDiary::DialogSaveDiary( void )
-        : Gtk::FileChooserDialog(
-                // TRANSLATORS: this is the title of filechooser dialog for saving a new diary
-                _( "Where to Save The Diary?" ),
-                Gtk::FILE_CHOOSER_ACTION_SAVE )
+: Gtk::FileChooserDialog(
+        // TRANSLATORS: this is the title of filechooser dialog for saving a new diary
+        _( "Where to Save The Diary?" ), Gtk::FILE_CHOOSER_ACTION_SAVE )
 {
     add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
     add_button( Gtk::Stock::OK, Gtk::RESPONSE_ACCEPT );
     set_do_overwrite_confirmation( true );
 }
 
+std::string
+DialogSaveDiary::get_filename( const std::string &extension )
+{
+    std::string fname( FileChooserDialog::get_filename() );
+
+    if( ! extension.empty() && extension != "." )
+        if( ! str_ends_with( fname, extension ) )
+            fname.append( extension );
+
+    return fname;
+}
+
+std::string
+DialogSaveDiary::get_filename_default( void ) // appends default diary extension
+{
+    return get_filename( Lifeobase::settings.diary_extension );
+}
+
+// DIALOGOPENDIARY =================================================================================
+bool DialogOpenDiary::flag_filters_created = false;
+Glib::RefPtr< Gtk::FileFilter > DialogOpenDiary::filter_any;
+Glib::RefPtr< Gtk::FileFilter > DialogOpenDiary::filter_diary;
+
+DialogOpenDiary::DialogOpenDiary( void )
+:   Gtk::FileChooserDialog(
+        // TRANSLATORS: this is the title of filechooser dialog for selecting a new diary
+        _( "Select a Diary" ), Gtk::FILE_CHOOSER_ACTION_OPEN )
+{
+    add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
+    add_button( Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT );
+
+    init_filters();
+    add_filter( filter_any );
+    add_filter( filter_diary );
+    set_filter( filter_diary );
+}
+
+void
+DialogOpenDiary::init_filters( void )
+{
+    if( flag_filters_created )
+        return;
+
+    filter_any = Gtk::FileFilter::create();
+    filter_diary = Gtk::FileFilter::create();
+
+    filter_any->set_name( _( "All Files" ) );
+    filter_any->add_pattern( "*" );
+    filter_diary->set_name( _( "Diary Files" ) );
+    filter_diary->add_mime_type( "application/x-lifeographdiary" );
+
+    flag_filters_created = true;
+}
+
 // DIALOG PASSWORD PROMPT ==========================================================================
 DialogPasswordPrompt::DialogPasswordPrompt( BaseObjectType* cobject,
-        const Glib::RefPtr< Gtk::Builder > &refbuilder )
-        : DialogEvent( cobject, refbuilder )
+                                            const Glib::RefPtr< Gtk::Builder > &refbuilder )
+:   DialogEvent( cobject, refbuilder )
 {
     Lifeobase::builder->get_widget_derived( "entry_import_password", m_entry );
     set_response_sensitive( RESPONSE_GO, false );
@@ -68,9 +122,8 @@ DialogPasswordPrompt::handle_entry_changed( void )
 
 // DIALOG IMPORT ===================================================================================
 DialogImport::DialogImport( BaseObjectType* cobject,
-        const Glib::RefPtr< Gtk::Builder > &refbuilder )
-        : DialogEvent( cobject, refbuilder ), m_dialog_password( NULL ), m_diary(
-                NULL )
+                            const Glib::RefPtr< Gtk::Builder > &refbuilder )
+:   DialogEvent( cobject, refbuilder ), m_dialog_password( NULL ), m_diary( NULL )
 {
     Lifeobase::builder->get_widget( "filebutton_import_diary",
             m_file_chooser_button );
@@ -88,6 +141,12 @@ DialogImport::DialogImport( BaseObjectType* cobject,
     Lifeobase::builder->get_widget( "checkbutton_import_themes",
             m_checkbutton_import_themes );
 
+    // FILTERING
+    DialogOpenDiary::init_filters();
+    m_file_chooser_button->add_filter( DialogOpenDiary::filter_any );
+    m_file_chooser_button->add_filter( DialogOpenDiary::filter_diary );
+    m_file_chooser_button->set_filter( DialogOpenDiary::filter_diary );
+
     // SIGNALS
     m_file_chooser_button->signal_file_set().connect(
             sigc::mem_fun( this, &DialogImport::handle_diary_changed ) );
@@ -129,8 +188,7 @@ DialogImport::handle_diary_changed( void )
 
     m_diary = new Diary;
 
-    m_diary->set_read_only( true );
-    m_diary->set_path( m_file_chooser_button->get_filename() );
+    m_diary->set_path( m_file_chooser_button->get_filename(), false, true );
 
     if( m_diary->read_header() == SUCCESS )
     {
@@ -249,12 +307,10 @@ DialogImport::on_response( int response )
 // DIALOGEXPORT ====================================================================================
 DialogExport::DialogExport( BaseObjectType* cobject,
         const Glib::RefPtr< Gtk::Builder > &refbuilder )
-:   DialogEvent( cobject, refbuilder ), m_ptr2widget_options( NULL ),
-    m_ptr2diary( Diary::d )
+:   DialogEvent( cobject, refbuilder ), m_ptr2widget_options( NULL ), m_ptr2diary( Diary::d )
 {
-    Lifeobase::builder->get_widget_derived( "combo_export_type", m_combo_type );
-    Lifeobase::builder->get_widget_derived( "combo_export_extent",
-            m_combo_extent );
+    Lifeobase::builder->get_widget( "combo_export_type", m_combo_type );
+    Lifeobase::builder->get_widget( "combo_export_extent", m_combo_extent );
     Lifeobase::builder->get_widget( "frame_export_options", m_frame_options );
     Lifeobase::builder->get_widget( "align_export_options", m_align_options );
     Lifeobase::builder->get_widget( "button_export_go", m_button_export );
@@ -262,8 +318,8 @@ DialogExport::DialogExport( BaseObjectType* cobject,
     add_saver( new ExporterLifeograph( m_ptr2diary ) );
     add_saver( new ExporterText( m_ptr2diary ) );
 
-    m_combo_extent->append_text( _( "All Entries" ) );
-    m_combo_extent->append_text( _( "Only Filtered Entries" ) );
+    m_combo_extent->append( _( "All Entries" ) );
+    m_combo_extent->append( _( "Only Filtered Entries" ) );
     m_combo_extent->set_active( 0 );
 
     m_combo_type->signal_changed().connect(
@@ -278,7 +334,7 @@ void
 DialogExport::add_saver( Diarysaver *saver )
 {
     m_savers.push_back( saver );
-    m_combo_type->append_text( saver->get_name() );
+    m_combo_type->append( saver->get_name() );
     saver->signal_updated().connect(
             sigc::mem_fun( this, &DialogExport::handle_saver_updated ) );
 }
@@ -322,8 +378,7 @@ DialogExport::on_response( int response )
     if( response == RESPONSE_GO )
     {
         DialogSaveDiary *ds( new DialogSaveDiary );
-        ds->set_current_folder(
-                Glib::path_get_dirname( m_ptr2diary->get_path() ) );
+        ds->set_current_folder( Glib::path_get_dirname( m_ptr2diary->get_path() ) );
         ds->set_current_name( m_ptr2diary->get_name() + ".backup" );
 
         if( ds->run() == Gtk::RESPONSE_ACCEPT )
@@ -418,7 +473,7 @@ ExporterLifeograph::handle_encryption_changed( void )
 Result
 ExporterLifeograph::save( const std::string &path, bool filtered )
 {
-    if( m_flag_encrypted && m_passphrase.size() < LIFEO::PASSPHRASE_MIN_SIZE )
+    if( m_flag_encrypted && m_passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE )
         return m_ptr2diary->write_copy( path, m_passphrase, filtered );
     else
         return m_ptr2diary->write_copy( path, "", filtered );
