@@ -27,7 +27,7 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 
-#include "lifeobase.hpp"
+#include "helpers.hpp"
 
 
 namespace LIFEO
