@@ -30,6 +30,8 @@
 #include <iostream>
 #include <fstream>
 #include <gcrypt.h>
+#include <cerrno>
+#include <cassert>
 
 #include "diary.hpp"
 #include "helpers.hpp"
@@ -77,8 +79,8 @@ get_db_line_name( const Glib::ustring &line )
 Diary::Diary( void )
 :   DiaryElement( this ), m_path( "" ), m_passphrase( "" ),
     m_ptr2chapter_ctg_cur( NULL ), m_topics( this, "topics" ),
-    m_default_theme( ThemeSystem::get() ), m_startup_elem( HOME_CURRENT_ELEM ),
-    m_last_elem( DEID_MIN ),
+    m_default_theme( ThemeSystem::get() ),
+    m_startup_elem( HOME_CURRENT_ELEM ), m_last_elem( DEID_MIN ),
     m_option_spellcheck( false ), m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
 #ifdef LIFEOGRAPH_DEBUG_BUILD
     m_flag_ignore_locks( true ),
@@ -89,24 +91,20 @@ Diary::Diary( void )
     m_filter_text( "" ), m_filter_tag( NULL ), m_filter_date_begin( 0 ),
     m_filter_date_end( Date::DATE_MAX ), m_filtering_status( FS_CLEAR )
 {
-	// add system theme to the pool where it will remain till the diary is destroyed:
-	m_themes.insert( PoolThemes::value_type( m_default_theme->get_name(), m_default_theme ) );
+    // system theme added back to m_themes:
+    m_themes.insert( PoolThemes::value_type( STRING::SYSTEM_THEME, ThemeSystem::get() ) );
 }
 
 Diary::~Diary( void )
 {
-	if( ! m_path.empty() )
-	{
-		std::string path_lock = m_path + LOCK_SUFFIX;
-		remove( path_lock.c_str() );
-	}
+	remove_lock();
 }
 
 void
 Diary::init_new( const std::string &path )
 {
     clear();
-    set_path( path );
+    set_path( path, true );
     add_today();
     // every diary must at least have one chapter category:
     m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
@@ -115,12 +113,9 @@ Diary::init_new( const std::string &path )
 void
 Diary::clear( void )
 {
-	if( ! m_path.empty() )
-	{
-		std::string path_lock = m_path + LOCK_SUFFIX;
-		remove( path_lock.c_str() );
-		m_path.clear();
-	}
+    if( remove_lock() )
+        m_path.clear();
+
 	m_read_version = 0;
 	DiaryBase::clear();			// clear IDs
 	create_new_id( this );		// add DEID_MIN back to IDs pool
@@ -157,34 +152,56 @@ Diary::get_icon( void ) const
 }
 
 bool
-Diary::set_path( const std::string &path )
+Diary::set_path( const std::string &path, bool new_file, bool read_only )
 {
-	std::string path_lock;
-
-    // remove existing lock
-    if( ! m_path.empty() )
+    // CHECK PERMISSIONS
+    FILE *fp = fopen( path.c_str(), "r+" );
+    if( fp == NULL )
     {
-        path_lock = m_path + LOCK_SUFFIX;
-        remove( path_lock.c_str() );
+        switch( errno )
+        {
+            case ENOENT:
+                if( ! new_file )
+                {
+                    print_error( "File not found" );
+                    return false;
+                }
+                break;
+            case EACCES:
+                print_error( "No permission" );
+                read_only = true;
+                break;
+        }
     }
+    else
+        fclose( fp );
 
-    path_lock = path + LOCK_SUFFIX;
-    if( Glib::file_test( path_lock, Glib::FILE_TEST_EXISTS ) )
+    // CHECK LOCK
+    std::string path_lock( path + LOCK_SUFFIX );
+    if( ! new_file && Glib::file_test( path_lock, Glib::FILE_TEST_EXISTS ) )
     {
         if( m_flag_ignore_locks )
             print_info( "ignored file lock" );
         else
-        if( ! m_flag_read_only )
+        if( ! read_only )
             return false;
     }
 
-	m_path = path;
-	m_name = Glib::filename_display_basename( path );
+    if( ! new_file ) // init_new() clears diary first, so not necessary there
+        remove_lock(); // remove existing lock
 
-	// "touch" new lock
-	FILE *fp = fopen( path_lock.c_str(), "a+" );
-	if( fp )
-		fclose( fp );
+    // ACCEPT PATH
+    m_path = path;
+    m_name = Glib::filename_display_basename( path );
+    m_flag_read_only = read_only;
+
+	// "TOUCH" THE NEW LOCK
+    if( ! read_only && ! new_file )
+    {
+        fp = fopen( path_lock.c_str(), "a+" );
+        if( fp )
+            fclose( fp );
+    }
 
     return true;
 }
@@ -426,12 +443,7 @@ Diary::parse_db_body_text( std::stringstream &stream )
 	while( getline( stream, line ) )
 	{
 		if( line[ 0 ] == 0 )	// end of section
-		{
-			// every diary must at least have one chapter category:
-			if( m_chapter_categories.empty() )
-				m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
 			break;
-		}
 		else
 		if( line.size() < 3 )
 			continue;
@@ -571,6 +583,9 @@ Diary::parse_db_body_text( std::stringstream &stream )
 					PoolThemes::iterator iter_theme( m_themes.find( line.substr( 2 ) ) );
 					if( iter_theme != m_themes.end() )
 						entry_new->set_theme( iter_theme->second );
+					// system theme added back to m_themes:
+					//else if( line.substr( 2 ) == STRING::SYSTEM_THEME )
+					//    entry_new->set_theme( ThemeSystem::get() );
 					else
 						print_error( "Reference to undefined theme: " + line.substr( 2 ) );
 				}
@@ -613,6 +628,10 @@ Diary::parse_db_body_text( std::stringstream &stream )
 		}
 	}
 
+    // every diary must at least have one chapter category:
+    if( m_chapter_categories.empty() )
+        m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
+
 	if( m_startup_elem > HOME_FIXED_ELEM )
 		if( get_element( m_startup_elem ) == NULL )
 		{
@@ -649,12 +668,7 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 	while( getline( stream, line ) )
 	{
 		if( line[ 0 ] == 0 )
-		{
-			// every diary must at least have one chapter category:
-			if( m_chapter_categories.empty() )
-				m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
 			break;
-		}
 		else
 		if( line.size() < 3 )
 			continue;
@@ -819,6 +833,10 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 		}
 	}
 
+    // every diary must at least have one chapter category:
+    if( m_chapter_categories.empty() )
+        m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
+
 	if( m_entries.size() )
 	{
 		return LIFEO::SUCCESS;
@@ -834,6 +852,8 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 LIFEO::Result
 Diary::write( void )
 {
+    assert( m_flag_read_only == false );
+
     m_flag_only_save_filtered = false;
 
 	std::string path_old( m_path + ".~previousversion~" );
@@ -922,6 +942,8 @@ Diary::write_txt( const std::string &path, bool flag_filtered )
                 {
                     chapters = Diary::d->get_topics();
                     iter_chapter = chapters->rbegin();
+                    if( iter_chapter == chapters->rend() )
+                        break;
                     flag_chapter_round = false;
                     continue;
                 }
@@ -977,7 +999,7 @@ Diary::write_txt( const std::string &path, bool flag_filtered )
 }
 
 LIFEO::Result
-Diary::write_plain( const std::string &path, bool flag_headeronly )
+Diary::write_plain( const std::string &path, bool flag_header_only )
 {
 	std::ofstream file( path.c_str(), std::ios::out | std::ios::trunc );
 	if( ! file.is_open() )
@@ -987,9 +1009,9 @@ Diary::write_plain( const std::string &path, bool flag_headeronly )
 	}
 
 	std::stringstream output;
-	create_db_header_text( output, flag_headeronly );
+	create_db_header_text( output, flag_header_only );
 	// header only mode is for encrypted diaries
-	if( ! flag_headeronly )
+	if( ! flag_header_only )
 	{
 		create_db_body_text( output );
 	}
@@ -1051,7 +1073,7 @@ Diary::create_db_header_text( std::stringstream &output, bool encrypted )
 {
 	output << LIFEO::DB_FILE_HEADER;
 	output << "\nV " << LIFEO::DB_FILE_VERSION_INT;
-	output << "\nE " << ( encrypted ? "yes" : "no" );
+	output << ( encrypted ? "\nE yes" : "\nE no" );
 	output << "\n\n"; // end of header
 
 	return true;
@@ -1085,12 +1107,14 @@ Diary::create_db_body_text( std::stringstream &output )
 		 iter != m_tag_categories.end();
 		 ++iter )
 	{
-		output << "ID" << iter->second->get_id()
-               << "\nT" << ( iter->second->get_expanded() ? 'e' : ' ' )
-               << iter->second->get_name_std() << '\n';	// tag category
-		CategoryTags *category( iter->second );
-		for( CategoryTags::const_iterator iter_tag = category->begin();
-			 iter_tag != category->end();
+        // tag category:
+		CategoryTags *ctg( iter->second );
+		output << "ID" << ctg->get_id()
+               << "\nT" << ( ctg->get_expanded() ? 'e' : ' ' )
+               << ctg->get_name_std() << '\n';
+		// tags in it:
+		for( CategoryTags::const_iterator iter_tag = ctg->begin();
+			 iter_tag != ctg->end();
 			 ++iter_tag )
 		{
             output << "ID" << ( *iter_tag )->get_id()
@@ -1112,12 +1136,14 @@ Diary::create_db_body_text( std::stringstream &output )
 		 iter != m_chapter_categories.end();
 		 ++iter )
 	{
-		CategoryChapters *category( iter->second );
-        output << "ID" << category->get_id()
-               << "\nC" << ( category == m_ptr2chapter_ctg_cur ? 'c' : ' ' )
-               << category->get_name_std() << '\n';
-		for( CategoryChapters::iterator iter_chapter = category->begin();
-			 iter_chapter != category->end();
+        // chapter category:
+		CategoryChapters *ctg( iter->second );
+        output << "ID" << ctg->get_id()
+               << "\nC" << ( ctg == m_ptr2chapter_ctg_cur ? 'c' : ' ' )
+               << ctg->get_name_std() << '\n';
+        // chapters in it:
+		for( CategoryChapters::iterator iter_chapter = ctg->begin();
+			 iter_chapter != ctg->end();
 			 ++iter_chapter )
 		{
             output << "ID" << iter_chapter->second->get_id()
@@ -1140,11 +1166,11 @@ Diary::create_db_body_text( std::stringstream &output )
                << "\nM" << ( theme == m_default_theme ? 'd' : ' ' )
                << theme->get_name_std() << '\n';
         output << "mf" << theme->font.to_string() << '\n';
-        output << "mb" << theme->color_base.to_string() << '\n';
-        output << "mt" << theme->color_text.to_string() << '\n';
-        output << "mh" << theme->color_heading.to_string() << '\n';
-        output << "ms" << theme->color_subheading.to_string() << '\n';
-        output << "ml" << theme->color_highlight.to_string() << '\n';
+        output << "mb" << convert_gdkrgba_to_string( theme->color_base ) << '\n';
+        output << "mt" << convert_gdkrgba_to_string( theme->color_text ) << '\n';
+        output << "mh" << convert_gdkrgba_to_string( theme->color_heading ) << '\n';
+        output << "ms" << convert_gdkrgba_to_string( theme->color_subheading ) << '\n';
+        output << "ml" << convert_gdkrgba_to_string( theme->color_highlight ) << '\n';
 	}
 
 	output << '\n'; // end of section
@@ -1273,6 +1299,18 @@ Diary::get_prev_session_elem( void )
 	return get_element( m_last_elem );
 }
 
+// LOCKS ===========================================================================================
+inline bool
+Diary::remove_lock( void )
+{
+    if( m_path.empty() )
+        return false;
+
+    std::string path_lock( m_path + LOCK_SUFFIX );
+    remove( path_lock.c_str() );
+    return true;
+}
+
 // ENTRIES =========================================================================================
 Entry*
 Diary::add_today( void )
@@ -1294,6 +1332,7 @@ Diary::get_entry( const Date::date_t date )
 Entry*
 Diary::get_entry_today( void )
 {
+    // FIXME: handle filtered out case
     return get_entry( Date::get_today( 1 ) );  // 1 is the order
 }
 
@@ -1866,6 +1905,10 @@ Diary::make_free_entry_order( Date &date )
 Theme*
 Diary::create_theme( const Glib::ustring& name )
 {
+    // system theme added back to m_themes:
+//    if( name == STRING::SYSTEM_THEME )
+//        return ThemeSystem::get();
+
 	PoolThemes::iterator iter = m_themes.find( name );
 	if( iter != m_themes.end() )
 		return( iter->second );
