@@ -104,12 +104,7 @@ class Diary : public DiaryBase, public DiaryElement
 		Glib::RefPtr< Gdk::Pixbuf >&
 								get_icon( void ) const;
 
-		Glib::ustring			get_list_str( void ) const
-		{ return Glib::ustring::compose( "<b>%1</b>",
-				Glib::Markup::escape_text(
-						Glib::filename_display_basename( m_path ) ) ); }
-
-		bool					set_path( const std::string& );
+		bool					set_path( const std::string&, bool, bool = false );
 		const std::string&		get_path( void ) const;
 		bool					is_path_set( void ) const;
 
@@ -119,8 +114,8 @@ class Diary : public DiaryBase, public DiaryElement
 		bool					compare_passphrase( const std::string& ) const;
 		bool					is_passphrase_set( void ) const;
 
-		void                    set_read_only( bool read_only )
-		{ m_flag_read_only = read_only; }
+        bool                    is_read_only( void ) const
+        { return m_flag_read_only; }
 
 		DiaryElement*			get_element( DEID );
 		DiaryElement*			get_startup_elem( void );
@@ -267,6 +262,8 @@ class Diary : public DiaryBase, public DiaryElement
 		LIFEO::Result			write_plain( const std::string&, bool = false );
 		LIFEO::Result			write_encrypted( const std::string& );
 
+		bool                    remove_lock();
+
 	private:
 		std::ios::pos_type		m_body_position;
 
