@@ -33,6 +33,13 @@
 namespace LIFEO
 {
 
+namespace STRING
+{
+const char SYSTEM_THEME[] = "[ - 0 - ]";
+}
+
+using namespace HELPERS;
+
 typedef char SortingCriteria;
 static const SortingCriteria SC_DATE	= 'd';
 static const SortingCriteria SC_SIZE	= 's';
@@ -120,7 +127,7 @@ class NamedElement
 
         Glib::ustring           get_name( void ) const
 		{ return m_name; }
-		std::string             get_name_std( void ) const
+		std::string             get_name_std( void ) const  // std::string version
 		{ return m_name; }
 		void					set_name( const Glib::ustring &name )
 		{ m_name = name; }
@@ -224,8 +231,44 @@ create_unique_name_for_map( const std::map< Glib::ustring, T*, FuncCompareString
 
 // ElementShower class is for communication between Diary and...
 // ...GUI classes. we may resort to signals if needed:
+class ElementShowerProto
+{
+    public:
+        virtual             ~ElementShowerProto() {}
+
+        virtual DiaryElement*   get_element( void ) = 0;
+
+        Gtk::Widget*            get_widget( void )
+        { return m_vbox; }
+        Gtk::Widget*            get_toolbar( void )
+        { return m_box_toolbar; }
+
+        virtual Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon_32( void ) const = 0;
+
+        virtual Glib::ustring   get_title_str( void ) const
+        { return ""; }
+        virtual Glib::ustring   get_info_str( void ) const
+        { return ""; }
+        virtual Glib::ustring   get_tip_str( void ) const
+        { return ""; }
+
+        virtual bool            is_title_editable( void ) const
+        { return false; }
+        virtual Glib::ustring   get_title_edit_str( void ) const
+        { return get_title_str(); }
+        virtual bool            check_title_applicable( const Glib::ustring& ) const
+        { return false; }
+        virtual bool            apply_title( const Glib::ustring& )
+        { return false; }
+
+    protected:
+        Gtk::Box                *m_vbox;
+        Gtk::Box                *m_box_toolbar;
+};
+
 template< class T >
-struct ElementShower
+struct ElementShower : public ElementShowerProto
 {
         virtual         ~ElementShower() {}
         virtual void    show( T& ) = 0;
@@ -328,9 +371,6 @@ class Tag : public DiaryElementContainer
 		Glib::RefPtr< Gdk::Pixbuf >&
 								get_icon( void ) const;
 
-		Glib::ustring			get_2nd_str( void ) const
-		{ return m_name; }
-
 	protected:
 		CategoryTags			*m_ptr2category;
 
@@ -390,14 +430,12 @@ class Chapter : public DiaryElement
 		Date					get_date( void ) const;
 		Glib::ustring			get_date_str( void ) const;
 		void					set_date( const Date& );
+		virtual int				get_size( void ) const	// TODO: stub!
+		{ return m_size; }
 		Type					get_type( void ) const
 		{ return ET_CHAPTER; }
 		Glib::RefPtr< Gdk::Pixbuf >&
 								get_icon( void ) const;
-		Glib::RefPtr< Gdk::Pixbuf >&
-								get_icon_32( void ) const;
-		virtual int				get_size( void ) const	// TODO: stub!
-		{ return m_size; }
 
 		Date					get_free_order( void ) const;
 
@@ -419,9 +457,11 @@ class Chapter : public DiaryElement
 		{ m_size = 0; }
 		void					increase_size()
 		{ m_size++; }
+        void                    recalculate_span( const Chapter* );
 
 	protected:
 		Date					m_date_begin;
+        int                     m_time_span;
 		int						m_size;
 		bool					m_flag_expanded;
 
@@ -442,6 +482,7 @@ class CategoryChapters :
 		{ return ET_CHAPTER_CTG; }
 		Glib::RefPtr< Gdk::Pixbuf >&
 								get_icon( void ) const;
+
 		void					show( void ) {}	// not used
 
 		Chapter*				get_chapter( const Date& );
@@ -451,6 +492,8 @@ class CategoryChapters :
 		bool					rename_chapter( Chapter*, const Glib::ustring& );
 		bool					set_chapter_date( Chapter*, const Date& );
 
+        bool                    add( Chapter* );
+
 		void					clear( void );
 
 		Date					get_free_order_ordinal( void ) const;
@@ -504,11 +547,11 @@ class Theme : public DiaryElement
 		{ return false; }
 
 		Pango::FontDescription		font;
-		Gdk::Color					color_base;
-		Gdk::Color					color_text;
-		Gdk::Color					color_heading;
-		Gdk::Color					color_subheading;
-		Gdk::Color					color_highlight;
+		Gdk::RGBA					color_base;
+		Gdk::RGBA					color_text;
+		Gdk::RGBA					color_heading;
+		Gdk::RGBA					color_subheading;
+		Gdk::RGBA					color_highlight;
 
 	friend class Diary;
 };
