@@ -74,13 +74,13 @@ Entry::calculate_title( const Glib::ustring &text )
 Glib::ustring
 Entry::get_date_created_str( void ) const
 {
-	return Date::format_string( &m_date_created );
+	return Date::format_string( m_date_created );
 }
 
 Glib::ustring
 Entry::get_date_changed_str( void ) const
 {
-	return Date::format_string( &m_date_changed );
+	return Date::format_string( m_date_changed );
 }
 
 void
