@@ -64,6 +64,8 @@ class Entry : virtual public DiaryElement
 		{ return ET_ENTRY; }
 		Glib::RefPtr< Gdk::Pixbuf >&
 								get_icon( void ) const;
+        Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon_32( void ) const;
 
 		void					calculate_title( const Glib::ustring& );
 
