@@ -496,27 +496,28 @@ EntryParser::trigger_link_date( void )
     lookingfor.push_back( LF_NUMBER );
     lookingfor.push_back( LF_DOTMD|LF_JUNCTION );
     lookingfor.push_back( LF_NUMBER );
+    lookingfor.push_back( LF_NUMBER|LF_JUNCTION );
 
     m_appliers.clear();
     m_appliers.push_back( &EntryParser::junction_date_dotym );
     m_appliers.push_back( &EntryParser::junction_date_dotmd );
+    m_appliers.push_back( &EntryParser::junction_link_date ); // checks validity of the date
 
     m_flag_hidden_link = ( word_last == "<" );
     if( m_flag_hidden_link )
     {
-        lookingfor.push_back( LF_NUMBER );
         lookingfor.push_back( LF_TAB|LF_JUNCTION );
         lookingfor.push_back( LF_NONSPACE );
         lookingfor.push_back( LF_MORE|LF_APPLY );
         pos_start = pos_current - 1;
         m_appliers.push_back( &EntryParser::junction_link_hidden_tab );
+        m_appliers.push_back( &EntryParser::apply_link_date );
     }
     else
     {
-        lookingfor.push_back( LF_NUMBER|LF_APPLY );
         pos_start = pos_current;
+        // applier is called by junction_link_date() in this case
     }
-    m_appliers.push_back( &EntryParser::apply_link_date );
 }
 
 void
@@ -547,6 +548,27 @@ EntryParser::trigger_ignore( void )
     }
 }
 
+void
+EntryParser::junction_link_date( void )
+{
+    date_last.set_day( int_last );
+
+    if( date_last.is_valid() )
+    {
+        if( m_flag_hidden_link )
+        {
+            lookingfor.pop_front();
+            m_appliers.pop_front();
+            return;
+        }
+        else
+            apply_link_date();
+    }
+
+    lookingfor.clear();
+    lookingfor.push_back( LF_NOTHING );
+}
+
 void
 EntryParser::junction_link_hidden_tab( void )
 {
