@@ -32,6 +32,8 @@
 namespace LIFEO
 {
 
+using namespace HELPERS;
+
 enum LookingFor
 {
     LF_NOTHING          = 0x1,
@@ -126,6 +128,7 @@ class EntryParser
         void                        trigger_link_date( void );
         void                        trigger_list( void );
         void                        trigger_ignore( void );
+        void                        junction_link_date( void );
         void                        junction_link_hidden_tab( void );
         void                        junction_list( void );
         void                        junction_date_dotym( void );   // dot between year and month
