@@ -170,7 +170,7 @@ Tagwidget::handle_icon_release( Gtk::EntryIconPosition, const GdkEventButton* ev
 TagWidget::TagWidget( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& b )
 :	EntryIdletext( cobject, b ), m_completion( Gtk::EntryCompletion::create() )
 {
-	set_idle_text( _( "Tag name" ) );
+	set_placeholder_text( _( "Tag name" ) );
 
 	m_completion->set_popup_completion( true );
 	m_completion->set_popup_single_match( true );
@@ -230,6 +230,7 @@ TagWidget::populate( void )
 
 // TAG PANEL =======================================================================================
 // STATIC MEMBERS
+TagPanel                *Lifeobase::panel_tag = NULL;
 TagPanel::Colrec		*TagPanel::colrec;
 
 TagPanel::TagPanel( void )
@@ -268,8 +269,9 @@ TagPanel::TagPanel( void )
 	m_treeview_all_tags->set_model( m_treestore_all_tags );
 	m_treeview_all_tags->append_column( *column_name_all );
 	m_treeview_all_tags->enable_model_drag_source( Lifeobase::base->drag_targets_tag );
-	m_treeview_all_tags->modify_base(
-			Gtk::STATE_NORMAL, Lifeobase::base->get_style()->get_bg( Gtk::STATE_NORMAL ) );
+	m_treeview_all_tags->override_background_color(
+            Lifeobase::base->get_style_context()->get_background_color( Gtk::STATE_FLAG_NORMAL ),
+            Gtk::STATE_FLAG_NORMAL );
 
 	// SIGNALS
 	m_treeview_all_tags->signal_row_activated().connect(
@@ -485,8 +487,8 @@ TagPanel::handle_treeview_row_activated( const Gtk::TreePath &path, Gtk::TreeVie
 			Diary::d->set_filter_tag( tag );
 			row[ colrec->icon ] = Lifeobase::icons->filter_16;
 		}
-        Lifeobase::base->update_button_filter_tag();
-        Lifeobase::base->update_button_remove_filters();
-        Lifeobase::base->update_entry_list();
+        Lifeobase::view_tag->update_button_filter_tag();
+        Lifeobase::panel_diary->update_button_remove_filters();
+        Lifeobase::panel_diary->update_entry_list();
 	}
 }
