@@ -33,35 +33,47 @@
 #include "helpers.hpp"
 
 
-using namespace LIFEO;
-
+namespace HELPERS
+{
 
 Error::Error( const Glib::ustring &error_message )
 {
 	print_error( error_message );
 }
 
-// DATE
+// DATE ============================================================================================
 Date::Date( const Glib::ustring &str_date )
-	:	m_date( 0 )
+:   m_date( 0 )
 {
 	Glib::Date glib_date;
 
 	glib_date.set_parse( str_date );
 
 	if( ! glib_date.valid() )
-		throw LIFEO::Error( "Date format not accepted" );
+		throw Error( "Date format not accepted" );
 
 	guint16 year = glib_date.get_year();
 
 	if( year < YEAR_MIN || year > YEAR_MAX )
-		throw LIFEO::Error( "Date out of acceptable range" );
+		throw Error( "Date out of acceptable range" );
 
 	m_date = ( year << 19 ) +
 			 ( glib_date.get_month() << 15 ) +
 			 ( glib_date.get_day() << 10 );
 }
 
+// TODO: later...
+//Date::Date( time_t t )
+//{
+//    struct tm *timeinfo = localtime( &t );
+//    m_date = make_date( timeinfo->tm_year + 1900,
+//                        timeinfo->tm_mon +1,
+//                        timeinfo->tm_mday );
+//    timeinfo->tm_hour = 0;
+//    timeinfo->tm_min = 0;
+//    timeinfo->tm_sec = 0;
+//}
+
 Glib::Date::Month
 Date::get_month_glib( void ) const
 {
@@ -115,9 +127,9 @@ Date::format_string( void ) const
 }
 
 Glib::ustring
-Date::format_string( const time_t *time )
+Date::format_string( const time_t time )
 {
-	struct tm *timeinfo = localtime( time );
+	struct tm *timeinfo = localtime( &time );
 	return Glib::ustring::compose( "%1.%2.%3, %4:%5",
 			1900 + timeinfo->tm_year,
 			Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mon + 1 ),
@@ -128,9 +140,9 @@ Date::format_string( const time_t *time )
 
 // date only
 Glib::ustring
-Date::format_string_do( const time_t *time )
+Date::format_string_do( const time_t time )
 {
-	struct tm *timeinfo = localtime( time );
+	struct tm *timeinfo = localtime( &time );
 	return Glib::ustring::compose( "%1.%2.%3",
 			1900 + timeinfo->tm_year,
 			Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mon + 1 ),
@@ -174,6 +186,20 @@ Date::get_weekday_str( void ) const
 	return Glib::ustring( buf );
 }
 
+unsigned int
+Date::get_days_in_month( void ) const
+{
+    switch( get_month() )
+    {
+        case 4: case 6: case 9: case 11:
+            return 30;
+        case 2:
+            return is_leap_year() ? 29 : 28;
+    }
+
+    return 31;
+}
+
 time_t
 Date::get_ctime( void ) const
 {
@@ -245,22 +271,31 @@ Date::forward_day( void )
 		set_day( day + 1 );
 }
 
+unsigned int
+Date::calculate_days_between( const Date &date2 ) const
+{
+    // TODO: create own implementation
+    Glib::Date gdate_begin( get_glib() );
+    Glib::Date gdate_end( date2.get_glib() );
+    return( gdate_begin.days_between( gdate_end ) );
+}
+
 // CONSOLE MESSAGES
 void
-LIFEO::print_error( const Glib::ustring &description )
+print_error( const Glib::ustring &description )
 {
 	std::cout << "ERROR: " << description << std::endl;
 }
 
 void
-LIFEO::print_info( const Glib::ustring &description )
+print_info( const Glib::ustring &description )
 {
 	std::cout << "INFO: " << description << std::endl;
 }
 
 // STRING PROCESSING
 long
-LIFEO::convert_string( const std::string &str )
+convert_string( const std::string &str )
 {
 	//TODO: add negative number support
 	long result( 0 );	// result
@@ -273,16 +308,29 @@ LIFEO::convert_string( const std::string &str )
 	return( result );
 }
 
+bool
+str_ends_with ( const std::string &str, std::string const &end )
+{
+    if( str.length() > end.length() )
+    {
+        return( str.compare( str.length() - end.length(), end.length(), end ) == 0 );
+    }
+    else
+    {
+        return false;
+    }
+}
+
 // COLOR PROCESSING
 //TODO: this needs lots of love...
-Gdk::Color
-LIFEO::contrast( const Gdk::Color &bg, const Gdk::Color &fg )
+Gdk::RGBA
+contrast( const Gdk::RGBA &bg, const Gdk::RGBA &fg )
 {
-	Gdk::Color contrast( fg );
+	Gdk::RGBA contrast( fg );
 	int dom_index = 0;	// 1,2,3 = R,G,B
-	int existingcontrast =	abs( fg.get_red() - bg.get_red() ) +
-							abs( fg.get_green() - bg.get_green() ) +
-							abs( fg.get_blue() - bg.get_blue() );
+	int existingcontrast =	abs( fg.get_red_u() - bg.get_red_u() ) +
+							abs( fg.get_green_u() - bg.get_green_u() ) +
+							abs( fg.get_blue_u() - bg.get_blue_u() );
 	if( existingcontrast > 32767 )
 		return contrast;
 
@@ -306,56 +354,58 @@ LIFEO::contrast( const Gdk::Color &bg, const Gdk::Color &fg )
 		case 0:
 		break;
 		case 1:
-			if( bg.get_red() > 32767 )
+			if( bg.get_red_u() > 32767 )
 			{
-				contrast.set_red( bg.get_red() - 32767 );// + existingcontrast );
+				contrast.set_red_u( bg.get_red_u() - 32767 );// + existingcontrast );
 //				contrast.set_green( 0 );
 //				contrast.set_blue( 0 );
 			}
 			else
 			{
-				contrast.set_red( bg.get_red() + 32767 );//- existingcontrast );
+				contrast.set_red_u( bg.get_red_u() + 32767 );//- existingcontrast );
 //				contrast.set_green( bg.get_green() > fg.get_green() ?
 //											fg.get_green()*0.5 :  );
 //				contrast.set_blue( 0 );
 			}
 		break;
 		case 2:
-			contrast.set_green( bg.get_green() > 32767 ?
-					fg.get_green() - 32767 :// + existingcontrast :
-					fg.get_green() + 32767 );// - existingcontrast );
+			contrast.set_green_u( bg.get_green_u() > 32767 ?
+					fg.get_green_u() - 32767 :// + existingcontrast :
+					fg.get_green_u() + 32767 );// - existingcontrast );
 		break;
 		case 3:
-			contrast.set_blue( bg.get_blue() > 32767 ?
-					bg.get_blue() - 32767 :// + existingcontrast :
-					bg.get_blue() + 32767 );// - existingcontrast );
+			contrast.set_blue_u( bg.get_blue_u() > 32767 ?
+					bg.get_blue_u() - 32767 :// + existingcontrast :
+					bg.get_blue_u() + 32767 );// - existingcontrast );
 		break;
 	}
 	return contrast;
 }
 
-Gdk::Color
-LIFEO::midtone( const Gdk::Color &c1, const Gdk::Color &c2 )
+Gdk::RGBA
+midtone( const Gdk::RGBA &c1, const Gdk::RGBA &c2 )
 {
-	Gdk::Color midtone;
-	midtone.set_red( ( c1.get_red() + c2.get_red() )>>1 );
-	midtone.set_green( ( c1.get_green() + c2.get_green() )>>1 );
-	midtone.set_blue( ( c1.get_blue() + c2.get_blue() )>>1 );
+	Gdk::RGBA midtone;
+	midtone.set_red_u( ( c1.get_red_u() + c2.get_red_u() ) / 2.0 );
+	midtone.set_green_u( ( c1.get_green_u() + c2.get_green_u() ) / 2.0 );
+	midtone.set_blue_u( ( c1.get_blue_u() + c2.get_blue_u() ) / 2.0 );
+	midtone.set_alpha( 1.0 );
 	return midtone;
 }
 
-Gdk::Color
-LIFEO::midtone( const Gdk::Color &c1, const Gdk::Color &c2, float ratio )
+Gdk::RGBA
+midtone( const Gdk::RGBA &c1, const Gdk::RGBA &c2, float ratio )
 {
-    Gdk::Color midtone;
-    midtone.set_red( ( c1.get_red() * ratio ) + ( c2.get_red() * ( 1.0 - ratio ) ) );
-    midtone.set_green( ( c1.get_green() * ratio ) + ( c2.get_green() * ( 1.0 - ratio ) ) );
-    midtone.set_blue( ( c1.get_blue() * ratio ) + ( c2.get_blue() * ( 1.0 - ratio ) ) );
+    Gdk::RGBA midtone;
+    midtone.set_red_u( ( c1.get_red_u() * ratio ) + ( c2.get_red_u() * ( 1.0 - ratio ) ) );
+    midtone.set_green_u( ( c1.get_green_u() * ratio ) + ( c2.get_green_u() * ( 1.0 - ratio ) ) );
+    midtone.set_blue_u( ( c1.get_blue_u() * ratio ) + ( c2.get_blue_u() * ( 1.0 - ratio ) ) );
+    midtone.set_alpha( 1.0 );
     return midtone;
 }
 // FILE FUNCTIONS
 std::ios::pos_type
-LIFEO::get_file_size( std::ifstream &file )
+get_file_size( std::ifstream &file )
 {
    std::ios::pos_type size;
    const std::ios::pos_type currentPosition = file.tellg();
@@ -369,7 +419,7 @@ LIFEO::get_file_size( std::ifstream &file )
 
 // URL HANDLERS
 void
-LIFEO::open_url( Gtk::AboutDialog&, const Glib::ustring &link )
+open_url( Gtk::AboutDialog&, const Glib::ustring &link )
 {
 	std::string command( "x-www-browser " );
 	command += link;
@@ -377,12 +427,6 @@ LIFEO::open_url( Gtk::AboutDialog&, const Glib::ustring &link )
 	// TODO: find a better way
 }
 
-void
-LIFEO::mail_to( Gtk::AboutDialog&, const Glib::ustring &link )
-{
-	// TODO: find a good way
-}
-
 // ENCRYPTION
 bool
 Cipher::init( void )
@@ -599,7 +643,7 @@ Cipher::decrypt_buffer (	unsigned char * buffer,
 
 // MARKED UP MENU ITEM
 Gtk::MenuItem*
-LIFEO::create_menuitem_markup(	const Glib::ustring &str_markup,
+create_menuitem_markup(	const Glib::ustring &str_markup,
 								const Glib::SignalProxy0< void >::SlotType &handler )
 {
 	// thanks to GNote for showing the way
@@ -613,14 +657,7 @@ LIFEO::create_menuitem_markup(	const Glib::ustring &str_markup,
 
 // ENTRYIDLETEXT ===================================================================================
 EntryIdletext::EntryIdletext( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
-	:	Gtk::Entry( cobject ), m_flag_empty( true )
-{
-	signal_icon_release().connect(
-			sigc::mem_fun( *this, &EntryIdletext::handle_clear_icon ) );
-}
-
-EntryIdletext::EntryIdletext( const Glib::ustring& idletext )
-: Gtk::Entry(), m_idletext( idletext ), m_flag_empty( true )
+	:	Gtk::Entry( cobject )
 {
 	signal_icon_release().connect(
 			sigc::mem_fun( *this, &EntryIdletext::handle_clear_icon ) );
@@ -633,27 +670,13 @@ EntryIdletext::handle_clear_icon( Gtk::EntryIconPosition icon_pos, const GdkEven
 		set_text( "" );
 }
 
-void
-EntryIdletext::on_map( void )
-{
-	Gdk::Color color = get_style()->get_text( Gtk::STATE_INSENSITIVE );
-
-	m_idletext.insert( 0, "\">" );
-	m_idletext.insert( 0, color.to_string() );
-	m_idletext.insert( 0, "<span foreground=\"" );
-	m_idletext.append( "</span>" );
-
-	Gtk::Entry::on_map();
-}
-
 void
 EntryIdletext::on_changed( void )
 {
-    m_flag_empty = get_text().empty();
-
-    if( m_flag_empty )
+    if( get_text().empty() )
     {
         // Fall-back to C API as gtkmm has problems with this:
+        // TODO: is this still the case with gtkmm-3?
         gtk_entry_set_icon_from_stock( gobj(), GTK_ENTRY_ICON_SECONDARY, 0 );
         set_icon_activatable( false, Gtk::ENTRY_ICON_SECONDARY );
     }
@@ -666,28 +689,10 @@ EntryIdletext::on_changed( void )
     Gtk::Entry::on_changed();
 }
 
-bool
-EntryIdletext::on_expose_event( GdkEventExpose *event )
-{
-	if( m_flag_empty && has_focus() == false)
-		get_layout()->set_markup( m_idletext );
-
-	return( Gtk::Entry::on_expose_event( event ) );
-}
-
-bool
-EntryIdletext::on_focus_in_event( GdkEventFocus *event )
-{
-	if( m_flag_empty )
-		get_layout()->set_markup( "" );
-
-	return( Gtk::Entry::on_focus_in_event( event ) );
-}
-
 bool
 EntryIdletext::on_key_release_event( GdkEventKey *event )
 {
-	if( event->keyval == GDK_Escape )
+	if( event->keyval == GDK_KEY_Escape )
 		set_text( "" );
 		
 	return Gtk::Entry::on_key_release_event( event );
@@ -707,7 +712,7 @@ Menubutton::Menubutton(	const Gtk::StockID &stockid,
 
 	if( menu == NULL )
 		m_menu = new Menu2;
-	Gtk::HBox *hbox = Gtk::manage( new Gtk::HBox );
+	Gtk::Box *hbox = Gtk::manage( new Gtk::Box );
 	m_icon = Gtk::manage( new Gtk::Image( stockid, iconsize ) );
 	m_label = Gtk::manage( new Gtk::Label( label ) );
 	Gtk::Arrow *arrow = Gtk::manage(
@@ -731,12 +736,12 @@ Menubutton::Menubutton(	const Glib::RefPtr< Gdk::Pixbuf > *pixbuf,
 {
 	set_relief( style );
 	Gtk::Arrow *arrow;
-	Gtk::HBox *hbox;
+	Gtk::Box *hbox;
 	try
 	{
 		if( menu == NULL )
 			m_menu = new Menu2;
-		hbox = Gtk::manage( new Gtk::HBox );
+		hbox = Gtk::manage( new Gtk::Box );
 		if( pixbuf )
 			m_icon = Gtk::manage( new Gtk::Image( *pixbuf ) );
 		m_label = Gtk::manage( new Gtk::Label( label ) );
@@ -769,7 +774,7 @@ Menubutton::Menubutton( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
     }
     catch( ... )
     {
-        throw LIFEO::Error( "Menubutton creation failed" );
+        throw Error( "Menubutton creation failed" );
     }
 
     m_menu->attach_to_widget( *this );
@@ -791,7 +796,7 @@ Menubutton::get_menu( void ) const
 bool
 Menubutton::clear_menu( void )
 {
-	if ( m_menu->items().size() > 0 )
+	if ( m_menu->get_children().size() > 0 )
 	{
 		delete m_menu;
 		m_menu = new Menu2;
@@ -899,10 +904,10 @@ MenuitemRecent::MenuitemRecent( const std::string &path )
 {
 	Gtk::Label		*label = Gtk::manage( new Gtk::Label(
 											Glib::filename_display_basename( path ) ) );
-	Gtk::HBox		*hbox = Gtk::manage( new Gtk::HBox );
+	Gtk::Box		*hbox = Gtk::manage( new Gtk::Box );
 
 	label->set_justify( Gtk::JUSTIFY_LEFT );
-	label->set_alignment( Gtk::ALIGN_LEFT );
+	label->set_alignment( Gtk::ALIGN_START );
 	label->set_ellipsize( Pango::ELLIPSIZE_START );
 	label->set_tooltip_text( path );
 	m_icon_remove.set_tooltip_text( _( "Remove from the list" ) );
@@ -966,6 +971,7 @@ MenuitemRecent::on_button_release_event( GdkEventButton *event )
 
 
 // FILEBUTTONRECENT ================================================================================
+#if( GTKMM_MAJOR_VERSION < 3 ) // to be ported to gtkmm3 if needed
 Glib::ustring   FilebuttonRecent::fallback_label = _( "Select or Create a Diary" );
 
 /*
@@ -1013,7 +1019,7 @@ FilebuttonRecent::FilebuttonRecent( BaseObjectType *cobj, const Glib::RefPtr<Gtk
     m_list_recent( NULL )
 {
     m_label->set_ellipsize( Pango::ELLIPSIZE_START );
-    m_label->set_alignment( Gtk::ALIGN_LEFT );
+    m_label->set_alignment( Gtk::ALIGN_START );
     m_label->set_text( fallback_label );
 
     m_menu->items().push_back( Gtk::Menu_Helpers::SeparatorElem() );
@@ -1237,4 +1243,32 @@ FilebuttonRecent::signal_create_file( void )
 {
 	return m_signal_createfile;
 }
+#endif
+// DIALOGEVENT =====================================================================================
+// the rest of the DialogEvent needs to be defined within the user application
+void
+DialogEvent::handle_logout( void )
+{
+    hide();
+}
 
+// FRAME (for printing) ============================================================================
+Gtk::Frame*
+create_frame( const Glib::ustring& str_label, Gtk::Widget& content )
+{
+    Gtk::Frame *frame = Gtk::manage( new Gtk::Frame );
+    Gtk::Label *label = Gtk::manage( new Gtk::Label );
+
+    Gtk::Alignment *alignment = Gtk::manage( new Gtk::Alignment );
+
+    label->set_markup( Glib::ustring::compose( "<b>%1</b>", str_label ) );
+    frame->set_shadow_type( Gtk::SHADOW_NONE );
+    frame->set_label_widget( *label );
+    alignment->set_padding( 0, 0, 12, 0 );
+    alignment->add( content );
+    frame->add( *alignment );
+
+    return frame;
+}
+
+} // end of name space
