@@ -30,6 +30,7 @@
 
 #include <iostream>
 #include <fstream>
+#include <set>
 
 #include <gcrypt.h>
 
@@ -44,7 +45,7 @@
 // END OF LIBGETTEXT DEFINITIONS
 
 
-namespace LIFEO
+namespace HELPERS
 {
 
 class Error
@@ -53,8 +54,6 @@ class Error
 						Error( const Glib::ustring& );
 };
 
-const unsigned int	MAX_RECENT_FILE_COUNT( 8 );
-
 // RESPONSE IDS
 static const int		RESPONSE_CANCEL		= 0;
 static const int		RESPONSE_GO			= 1;
@@ -105,6 +104,7 @@ class Date
 										  unsigned int o = 0 )
 			:	m_date( ( y << 19 ) | ( m << 15 ) | ( d << 10 ) | o ) {}
 		explicit					Date( const Glib::ustring& );
+		// TODO: later: explicit                    Date( time_t );
 		// ORDINAL C'TOR
 									Date( unsigned int o1, unsigned int o2 )
 			:	m_date( ORDINAL_FLAG | ( o1 << 10 ) | o2 ) {}
@@ -135,6 +135,21 @@ class Date
 		Glib::ustring				get_day_str( void ) const;
 		Glib::ustring		        get_weekday_str( void ) const;
 
+		unsigned int                get_days_in_month( void ) const;
+
+		bool                        is_leap_year( void ) const
+		{
+		    int year( get_year() );
+		    if( ( year % 400 ) == 0 )
+		        return true;
+		    else if( ( year % 100 ) == 0 )
+		        return false;
+		    else if( ( year % 4 ) == 0 )
+		        return true;
+
+		    return false;
+		}
+
 		unsigned int				get_month( void ) const
 		{ return( ( m_date & 0x78000 ) >> 15 ); }
         static unsigned int         get_month( const date_t d )
@@ -174,12 +189,14 @@ class Date
 		void						set_month( unsigned int m )
 		{
 			m_date &= 0xFFF87FFF;
-			m_date |= ( m << 15 );
+			if( m < 13 )
+			    m_date |= ( m << 15 );
 		}
 		void						set_day( unsigned int d )
 		{
 			m_date &= 0xFFFF83FF;
-			m_date |= ( d << 10 );
+			if( d < 32 )
+			    m_date |= ( d << 10 );
 		}
 		void						reset_order_0( void )
 		{ m_date &= 0xFFFFFC00; }
@@ -190,14 +207,14 @@ class Date
 
 		Glib::ustring				format_string( void ) const;
 		static Glib::ustring        format_string( const date_t );
-		static Glib::ustring		format_string( const time_t* );
-		static Glib::ustring		format_string_do( const time_t* );
+		static Glib::ustring		format_string( const time_t );
+		static Glib::ustring		format_string_do( const time_t );
 
 		static date_t               parse_string( const Glib::ustring& );
 
 		bool						is_valid( void ) const
 		{
-			return( Glib::Date::get_days_in_month( get_month_glib(), get_year() ) >= get_day() );
+			return( get_day() > 0 && get_day() <= get_days_in_month() );
 		}
 
 		bool						is_ordinal( void ) const
@@ -228,6 +245,8 @@ class Date
                                                unsigned int o = 0 )
 		{ return( ( y << 19 ) | ( m << 15 ) | ( d << 10 ) | o ); }
 
+        unsigned int                calculate_days_between( const Date& ) const;
+
 	//protected:
 		date_t						m_date;
 };
@@ -260,24 +279,35 @@ void				print_info( const Glib::ustring& );
 #endif
 
 long				convert_string( const std::string& );
+bool                str_ends_with ( const std::string&, std::string const& );
 
-Gdk::Color			contrast( const Gdk::Color&, const Gdk::Color& );
-Gdk::Color			midtone( const Gdk::Color&, const Gdk::Color& );
-Gdk::Color			midtone( const Gdk::Color&, const Gdk::Color&, float );
+Gdk::RGBA			contrast( const Gdk::RGBA&, const Gdk::RGBA& );
+Gdk::RGBA			midtone( const Gdk::RGBA&, const Gdk::RGBA& );
+Gdk::RGBA			midtone( const Gdk::RGBA&, const Gdk::RGBA&, float );
 
 inline Glib::ustring
-convert_gdkcolor_to_html( const Gdk::Color &gdkcolor )
+convert_gdkcolor_to_html( const Gdk::RGBA &gdkcolor )
 {
 	// this function's source of inspiration is Geany
 	char buffer[ 8 ];
 
 	g_snprintf(	buffer, 8, "#%02X%02X%02X",
-			gdkcolor.get_red() >> 8,
-			gdkcolor.get_green() >> 8,
-			gdkcolor.get_blue() >> 8 );
+			gdkcolor.get_red_u() >> 8,
+			gdkcolor.get_green_u() >> 8,
+			gdkcolor.get_blue_u() >> 8 );
 	return buffer;
 }
 
+inline Glib::ustring
+convert_gdkrgba_to_string( const Gdk::RGBA &gdkcolor )
+{
+    char buffer[ 14 ];
+    g_snprintf( buffer, 14, "#%04X%04X%04X",
+            int( gdkcolor.get_red() * 0xFFFF ),
+            int( gdkcolor.get_green() * 0xFFFF ),
+            int( gdkcolor.get_blue() * 0xFFFF ) );
+    return buffer;
+}
 std::ios::pos_type	get_file_size( std::ifstream& );
 
 void				open_url( Gtk::AboutDialog&, const Glib::ustring& );
@@ -288,7 +318,7 @@ Gtk::MenuItem*		create_menuitem_markup( const Glib::ustring&,
 
 // COMMON SIGNALS
 typedef sigc::signal< void >		SignalVoid;
-typedef std::list< std::string >	ListPaths;
+typedef std::set< std::string >	    ListPaths;
 
 // MEMORY POOL
 template< class T >
@@ -346,28 +376,20 @@ class Cipher
 
 };
 
-// ENTRY WIDGET WITH TIP TEXT WHEN IDLE
+// ENTRY WIDGET WITH TIP TEXT WHEN IDLE ============================================================
 class EntryIdletext : public Gtk::Entry
 {
 	public:
 							EntryIdletext( BaseObjectType*, const Glib::RefPtr<Gtk::Builder>& );
 		explicit			EntryIdletext( const Glib::ustring& );
 
-		void				set_idle_text( const Glib::ustring &idle_text )
-		{ m_idletext = idle_text; }
-
 	protected:
 		void				handle_clear_icon( Gtk::EntryIconPosition, const GdkEventButton* );
-		virtual void		on_map( void );
 		virtual void		on_changed( void );
-		virtual bool		on_expose_event( GdkEventExpose* );
-		virtual bool		on_focus_in_event( GdkEventFocus* );
 		virtual bool		on_key_release_event( GdkEventKey* );
-
-		Glib::ustring		m_idletext;
-		bool				m_flag_empty;
 };
 
+// MENU 2 ==========================================================================================
 class Menu2 : public Gtk::Menu
 {
 	public:
@@ -438,25 +460,25 @@ class Menutoolbutton : public Gtk::ToolItem
 };*/
 
 // FILE FILTERS
-class FilefilterAny : public Gtk::FileFilter
-{
-	public:
-		FilefilterAny()
-		{
-			set_name( _("All Files") );
-			add_pattern( "*" );
-		}
-};
-
-class FilefilterDiary : public Gtk::FileFilter
-{
-	public:
-		FilefilterDiary()
-		{
-			set_name( _("Diary Files (*.diary)") );
-			add_pattern( "*.diary" );
-		}
-};
+//class FilefilterAny : public Gtk::FileFilter
+//{
+//	public:
+//		FilefilterAny()
+//		{
+//			set_name( _("All Files") );
+//			add_pattern( "*" );
+//		}
+//};
+//
+//class FilefilterDiary : public Gtk::FileFilter
+//{
+//	public:
+//		FilefilterDiary()
+//		{
+//			set_name( _("Diary Files (*.diary)") );
+//			add_mime_type( "application/x-lifeographdiary" );
+//		}
+//};
 
 class MenuitemRecent : public Gtk::MenuItem
 {
@@ -482,9 +504,14 @@ class MenuitemRecent : public Gtk::MenuItem
 		Signal_void_string			m_signal_removerecent;
 };
 
+#if( GTKMM_MAJOR_VERSION < 3 )
+
 class FilebuttonRecent : public Menubutton
 {
 	public:
+        const unsigned int  MAX_RECENT_FILE_COUNT( 8 );
+
+        typedef std::list< std::string > ListPaths;
 //                                    FilebuttonRecent( const Glib::RefPtr< Gdk::Pixbuf >&,
 //                                                      ListPaths*, const Glib::ustring& );
                                     FilebuttonRecent( BaseObjectType*,
@@ -492,7 +519,7 @@ class FilebuttonRecent : public Menubutton
 
         void                        set( ListPaths* );
 
-		std::list< std::string >*	get_recentlist( void )
+		ListPaths*	                get_recentlist( void )
 		{
 			return m_list_recent;
 		}
@@ -529,8 +556,37 @@ class FilebuttonRecent : public Menubutton
 		SignalVoid					m_signal_selectionchanged;
 		SignalVoid					m_signal_createfile;
 };
+#endif
 
-} // end of namespace LIFEO
+// DIALOGEVENT =====================================================================================
+class DialogEvent : public Gtk::Dialog
+{
+    public:
+                            DialogEvent( const Glib::ustring& );
+                            DialogEvent( BaseObjectType*,
+                                         const Glib::RefPtr< Gtk::Builder >& );
+
+    protected:
+        bool                on_event( GdkEvent* );
+        void                handle_logout( void );
+
+};
+
+// COMBOBOXTEXT WITH GTK BUILDER (FOR GTKMM 2) =====================================================
+#if( GTKMM_MAJOR_VERSION < 3 )
+class ComboboxEasy : public Gtk::ComboBoxText
+{
+    public:
+                            ComboboxEasy( BaseObjectType* cobject,
+                                          const Glib::RefPtr< Gtk::Builder >& )
+    :   Gtk::ComboBoxText( cobject ) {}
+};
+#endif
+
+// FRAME FOR PRINTING ==============================================================================
+Gtk::Frame* create_frame( const Glib::ustring&, Gtk::Widget& );
+
+} // end of namespace HELPERS
 
 #endif
 
