@@ -28,13 +28,16 @@
 
 #include "settings.hpp"
 #include "diary.hpp"
+#include "panel_main.hpp"
+#include "panel_diary.hpp"
+#include "view_entry.hpp"
 
 
 namespace LIFEO
 {
 	const char			PROGRAM_NAME[]				= "Lifeograph";
-	const int			PROGRAM_VERSION_INT			= 8020;
-	const char			PROGRAM_VERSION_STRING[]	= "0.8.2";
+	const int			PROGRAM_VERSION_INT			= 9000;
+	const char			PROGRAM_VERSION_STRING[]	= "0.9.0";
 
 	const int			BACKUP_INTERVAL				= 30;	// seconds
 	const int			LOGOUT_COUNTDOWN			= 10;	// seconds
@@ -74,20 +77,20 @@ struct Icons
 class Lifeobase : public Gtk::Window
 {
 	public:
+        enum LoginStatus
+        {
+            LOGGED_OUT = 0, LOGGED_IN = 1, LOGGED_TIME_OUT = 2
+        };
+
 									Lifeobase();
 
 		static Lifeobase			*base;
-		static Settings				m_settings;
+		static Settings				settings;
 		static Icons				*icons;
 
-		static Glib::RefPtr<Gdk::Pixbuf>
-									pixbuf_background;
-
 		static Glib::RefPtr< Gtk::Builder >
 									builder;
 
-		Gtk::Widget					*m_contentwidget;
-
 		static void					create_action(
 				Glib::RefPtr< Gtk::Action >&,
 				/*Glib::RefPtr< Gtk::ActionGroup >&,*/
@@ -97,12 +100,17 @@ class Lifeobase : public Gtk::Window
 				const Glib::ustring&,
 				const Gtk::AccelKey&,
 				const Glib::SignalProxy0< void >::SlotType&,
-				Gtk::Widget* = NULL );
+				Gtk::Activatable* = NULL );
 
-		void						set_header_texts( const Glib::ustring&,
-													  const Glib::ustring&,
-													  const Glib::ustring& = "" );
-		static void					set_gelem_toolbar( Gtk::Widget* );
+        static void                 create_action(
+                Glib::RefPtr< Gtk::Action >&,
+                const Glib::ustring&,
+                const Glib::ustring&,
+                const Glib::ustring&,
+                const Glib::ustring&,
+                const Gtk::AccelKey&,
+                const Glib::SignalProxy0< void >::SlotType&,
+                Gtk::Activatable* = NULL );
 
 		virtual bool				on_event( GdkEvent* ) = 0;
 
@@ -110,39 +118,23 @@ class Lifeobase : public Gtk::Window
 
 		// communication functions
 		virtual void				logout( bool ) = 0;
-		virtual void				update_entry_list( void ) = 0;
-		virtual void				update_tag_list( void ) = 0;
-		virtual void				update_calendar( void ) = 0;
-		virtual void				update_button_filter_tag( void ) = 0;
-		virtual void				update_button_remove_filters( void ) = 0;
-		virtual void				update_tag_icon( const Tag* ) = 0;
-		virtual void				update_tag_categories( void ) = 0;
-		virtual void				select_date_in_calendar( const Date& ) = 0;
 		virtual void				update_theme_list( void ) = 0;
-		virtual void				sync_entry( void ) = 0;
 		virtual bool				confirm_dismiss_element( void ) = 0;
-		virtual void				remove_element_from_history( DiaryElement* ) = 0;
-		virtual bool				change_current_element( DiaryElement*, Gtk::Widget* ) = 0;
-		virtual void				handle_entry_title_changed( DiaryElement* ) = 0;
-		virtual void				handle_settings_changed( void ) = 0;
-		virtual DiaryElement*		get_cur_elem( void ) = 0;
-		virtual DiaryElement::Type	get_cur_elem_type( void ) = 0;
-		virtual DiaryElement*		get_dragged_elem( void ) = 0;
 		virtual Gtk::TreeRow		get_element_row( DiaryElement* ) = 0;
-		virtual void				focus_tag( void ) = 0;
-		virtual void				toggle_comments( void ) = 0;
+        virtual void                draw_editscreen( void ) = 0;
 
 		int							m_secondsremaining;
 		static int					m_internaloperation;
 		static int					m_entrycount;
-		static bool					flag_allocate_gui_for_dairy;
 
-		static Gtk::Button			*m_button_gui_elem;
-		static Gtk::Image			*m_image_gui_elem;
-		static Gtk::HBox			*m_hbox_gelem_header;
-		static Gtk::Widget			*m_current_gelem_toolbar;
-		Gtk::Label					*m_label_gui_elem;
-		Gtk::Label					*m_label_gui_elem_extra;
+		static PanelMain            *panel_main;
+		static PanelDiary           *panel_diary;
+		static TagPanel             *panel_tag;
+
+		static EntryView            *view_entry;
+        static TagView              *view_tag;
+
+        static std::set< std::string > stock_diaries;
 
 		std::vector< Gtk::TargetEntry >
 									drag_targets_tag;
@@ -154,6 +146,10 @@ class Lifeobase : public Gtk::Window
 		static SignalVoid			signal_logout( void )
 		{ return m_signal_logout; }
 
+        static LoginStatus          loginstatus;
+
+        bool                        m_flag_open_directly;
+
 	protected:
 		static sigc::connection		m_connection_timeout;
 
@@ -163,32 +159,6 @@ class Lifeobase : public Gtk::Window
 		static SignalVoid			m_signal_logout;
 };
 
-class DialogEvent : public Gtk::Dialog
-{
-	public:
-                            DialogEvent( const Glib::ustring& );
-                            DialogEvent( BaseObjectType*,
-                                         const Glib::RefPtr< Gtk::Builder >& );
-
-	protected:
-		bool				on_event( GdkEvent* );
-		void				handle_logout( void );
-
-};
-
-// this is necessary to use ComboboxText together with Gtk::Builder
-// till we upgrade to Gtkmm 3:
-class ComboboxEasy : public Gtk::ComboBoxText
-{
-    public:
-                            ComboboxEasy( BaseObjectType* cobject,
-                                          const Glib::RefPtr< Gtk::Builder >& )
-    :   Gtk::ComboBoxText( cobject ) {}
-};
-
-
-Gtk::Frame* create_frame( const Glib::ustring&, Gtk::Widget& );
-
 } // end of namespace LIFEO
 
 #endif
