@@ -34,17 +34,25 @@
 
 using namespace LIFEO;
 
+
+PanelDiary *Lifeobase::panel_diary = NULL;
+
 PanelDiary::PanelDiary( void )
 {
+    Gtk::Button *button_today;
 	try
 	{
-        Menubutton *mb_tools, *mb_add;
+        Menubutton *mb_tools;
+
+        Lifeobase::builder->get_widget( "button_today", button_today );
 
         Menubutton::s_builder_name = "menubutton_tools";
         Lifeobase::builder->get_widget_derived( Menubutton::s_builder_name, mb_tools );
         Lifeobase::builder->get_widget( "menuitem_sort_by_date", m_menuitem_sort_by_date );
         Lifeobase::builder->get_widget( "menuitem_sort_by_size", m_menuitem_sort_by_size );
 
+        Lifeobase::builder->get_widget( "sprt_tb_1", m_sprt_tb1 );
+
         Lifeobase::builder->get_widget( "togglebtn_filter_favorites",
                                         m_togglebtn_filter_favorites );
         Lifeobase::builder->get_widget( "button_remove_filters", m_button_remove_filters );
@@ -60,7 +68,7 @@ PanelDiary::PanelDiary( void )
 		Lifeobase::builder->get_widget( "hbox_toolbar_replace", m_toolbar_replace );
 
         Menubutton::s_builder_name = "menubutton_diary_add";
-        Lifeobase::builder->get_widget_derived( Menubutton::s_builder_name, mb_add );
+        Lifeobase::builder->get_widget_derived( Menubutton::s_builder_name, m_button_add );
         Lifeobase::builder->get_widget( "mnitem_add_entry", m_menuitem_add_entry );
         Lifeobase::builder->get_widget( "mnitem_add_chapter", m_menuitem_add_chapter );
         Lifeobase::builder->get_widget( "mnitem_add_topic", m_menuitem_add_topic );
@@ -68,8 +76,8 @@ PanelDiary::PanelDiary( void )
 	catch( ... ) { }
 
 	// FILTER & REPLACE
-	m_entry_filter->set_idle_text( _( "Filter" ) );
-	m_entry_replace->set_idle_text( _( "Replace" ) );
+	m_entry_filter->set_placeholder_text( _( "Filter" ) );
+	m_entry_replace->set_placeholder_text( _( "Replace" ) );
 
 	// SIGNALS
     m_menuitem_sort_by_date->signal_activate().connect(
@@ -118,6 +126,79 @@ PanelDiary::PanelDiary( void )
             sigc::mem_fun( this, &PanelDiary::handle_add_topic ) );
     m_menuitem_add_chapter->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_chapter ) );
+
+    // ACTIONS
+    Lifeobase::create_action(
+            m_action_today,
+            "Today",
+            "x-office-calendar",
+            _( "Today" ),
+            _( "Go to today (creates a new entry if there isn't any or when already at today)" ),
+            Gtk::AccelKey( GDK_KEY_d, Gdk::CONTROL_MASK ),
+            sigc::mem_fun( this, &PanelDiary::show_today ),
+            button_today );
+
+    Lifeobase::create_action(
+            m_action_focusfilter,
+            "FocusFilter",
+            Gtk::Stock::FIND,
+            "", "",     // no grachical interface yet!
+            Gtk::AccelKey( GDK_KEY_f, Gdk::CONTROL_MASK ),
+            sigc::mem_fun( m_entry_filter, &Gtk::Widget::grab_focus ) );
+
+    Lifeobase::create_action(
+            m_action_previous_list, "ListPrevious", Gtk::Stock::GO_UP, _( "Previous" ),
+            _( "Go to the previous entry in the list" ),
+            Gtk::AccelKey( GDK_KEY_Page_Up, Gdk::CONTROL_MASK ),
+            sigc::bind( sigc::mem_fun( m_treeview_entries, &WidgetEntryList::go_up ), false ) );
+
+    Lifeobase::create_action(
+            m_action_next_list, "ListNext", Gtk::Stock::GO_DOWN, _( "Next" ),
+            _( "Go to the next entry in the list" ),
+            Gtk::AccelKey( GDK_KEY_Page_Down, Gdk::CONTROL_MASK ),
+            sigc::bind( sigc::mem_fun( m_treeview_entries, &WidgetEntryList::go_down ), false ) );
+
+    Lifeobase::create_action(
+            m_action_previous_match,
+            "MatchPrevious",
+            Gtk::Stock::GO_BACK,
+// TRANSLATORS: label and tooltip of the go-to-previous-match-of-filtered-text action
+            _( "Previous Match" ),
+            _( "Go to previous match" ),
+            Gtk::AccelKey( GDK_KEY_F3, Gdk::SHIFT_MASK ),
+            sigc::mem_fun( this, &PanelDiary::go_prev_match ),
+            m_button_match_prev );
+
+    Lifeobase::create_action(
+            m_action_next_match,
+            "MatchNext",
+            Gtk::Stock::GO_FORWARD,
+// TRANSLATORS: label and tooltip of the go-to-next-match-of-filtered-text action
+            _( "Next Match" ),
+            _( "Go to next match" ),
+            Gtk::AccelKey( GDK_KEY_F3, Gdk::ModifierType( 0 ) ),
+            sigc::mem_fun( this, &PanelDiary::go_next_match ),
+            m_button_match_next );
+
+    Lifeobase::create_action(
+            m_action_jump2current,
+            "Jump",
+            Gtk::Stock::JUMP_TO,
+            "", "",     // no grachical interface yet!
+            Gtk::AccelKey( GDK_KEY_j, Gdk::CONTROL_MASK ),
+            sigc::mem_fun( this, &PanelDiary::present_current_row ) );
+
+    Lifeobase::create_action(
+            m_action_show_prev_session_elem,
+            "PrevSessElem",
+            Gtk::Stock::JUMP_TO,
+            "", "",     // no grachical interface yet!
+            Gtk::AccelKey( GDK_KEY_l, Gdk::CONTROL_MASK ),
+            sigc::mem_fun( this, &PanelDiary::show_prev_session_elem ) );
+
+    // becoming proxy widgets makes them visible:
+    m_button_match_prev->set_visible( false );
+    m_button_match_next->set_visible( false );
 }
 
 void
@@ -175,6 +256,19 @@ PanelDiary::add_chapter_category_to_list( const CategoryChapters *chapters )
 	}
 }
 
+// obviously not needed anymore:
+//void
+//PanelDiary::update_toolbar( void )
+//{
+//    bool flag_sensitive =
+//            Lifeobase::panel_main->get_cur_elem_type() ==
+//                    //DiaryElement::ET_ENTRY ? m_entrycount > 1 :
+//                    ( m_treeview_entries->m_treestore_entries->children().size() > 1 );
+//
+//    m_action_previous_list->set_sensitive( flag_sensitive );
+//    m_action_next_list->set_sensitive( flag_sensitive );
+//}
+
 void
 PanelDiary::update_entry_list( void )
 {
@@ -184,7 +278,7 @@ PanelDiary::update_entry_list( void )
 	l_itr_entry = Diary::d->m_entries.begin();
 	l_entry = ( l_itr_entry != Diary::d->m_entries.end() ? l_itr_entry->second : NULL );
 
-	Lifeobase::base->sync_entry();
+	Lifeobase::view_entry->sync();
 
 	m_treeview_entries->m_treestore_entries->clear();
 	Lifeobase::m_entrycount = 0;
@@ -229,7 +323,7 @@ PanelDiary::update_entry_list( void )
 	m_treeview_entries->expand_element( Diary::d );
 
 	// UPDATE DIARY ELEM IF LAST ONE IS NOT IN THE LIST ANYMORE
-	DiaryElement *elem = Lifeobase::base->get_cur_elem();
+	DiaryElement *elem = Lifeobase::panel_main->get_cur_elem();
 	bool flag_show_elem = true;
 	if( Lifeobase::m_entrycount <= 0 )
 		elem = Diary::d;
@@ -259,6 +353,21 @@ PanelDiary::update_entry_list( void )
 	Lifeobase::m_internaloperation--;
 }
 
+void
+PanelDiary::update_entry_list_style( void ) // TODO: is this function really needed?
+{
+    Lifeobase::m_internaloperation++;
+
+    update_entry_list();
+
+    if( Lifeobase::panel_main->get_cur_elem_type() != DiaryElement::ET_ENTRY )
+        Diary::d->show();
+
+    m_treeview_entries->columns_autosize();
+
+    Lifeobase::m_internaloperation--;
+}
+
 void
 PanelDiary::update_calendar( void )
 {
@@ -293,6 +402,14 @@ PanelDiary::update_calendar( void )
 	}
 }
 
+void
+PanelDiary::update_button_remove_filters( void )
+{
+    m_button_remove_filters->set_visible(
+            Diary::d->get_filtering_status() &
+            ( Diary::FS_FILTER_DATE | Diary::FS_FILTER_TAG ) );
+}
+
 void
 PanelDiary::handle_login( void )
 {
@@ -304,6 +421,12 @@ PanelDiary::handle_login( void )
 	// not called automatically because of m_internaloperation:
 	m_treeview_entries->set_sorting_criteria();
 	update_entry_list();
+
+    m_button_remove_filters->set_visible( false );
+
+	m_action_today->set_visible( ! Diary::d->is_read_only() );
+	m_button_add->set_visible( ! Diary::d->is_read_only() );
+	m_sprt_tb1->set_visible( ! Diary::d->is_read_only() );
 }
 
 void
@@ -343,6 +466,28 @@ PanelDiary::show( const DiaryElement *element )
 	}
 }
 
+void
+PanelDiary::show_today( void )
+{
+    Entry *entry_today = Diary::d->get_entry_today();
+    bool flag_add = false;
+
+    if( entry_today == NULL )   // add new entry if no entry exists on selected date
+        flag_add = true;
+    else                        // or current entry is already at today
+    if( entry_today->get_date().get_pure() ==
+                Lifeobase::panel_main->get_cur_elem()->get_date().get_pure() )
+        flag_add = true;
+
+    if( flag_add )
+    {
+        entry_today = Diary::d->add_today();
+        update_entry_list();
+    }
+
+    entry_today->show();
+}
+
 void
 PanelDiary::show_prev_session_elem( void )
 {
@@ -370,7 +515,7 @@ PanelDiary::handle_entry_filter_changed( void )
 	if( Lifeobase::m_internaloperation ) return;
 	// current entry must be closed here or else it loses...
 	// ...changes since it was selected:
-	Lifeobase::base->sync_entry();
+	Lifeobase::view_entry->sync();
 
 	const std::string filterstring( m_entry_filter->get_text().lowercase() );
 
@@ -382,7 +527,7 @@ PanelDiary::handle_entry_filter_changed( void )
 		if( Lifeobase::m_entrycount > 0 )
 		{
 			TextviewDiary::m_buffer->set_search_str( filterstring );
-			if( Lifeobase::base->get_cur_elem_type() == DiaryElement::ET_ENTRY )
+			if( Lifeobase::panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
 				TextviewDiary::m_buffer->select_searchstr_next();
 		}
 
@@ -409,7 +554,8 @@ PanelDiary::handle_entry_filter_changed( void )
 	{
 		m_button_match_prev->show();
 		m_button_match_next->show();
-		m_toolbar_replace->show();
+        if( ! Diary::d->is_read_only() )
+            m_toolbar_replace->show();
 	}
 }
 
@@ -431,8 +577,8 @@ PanelDiary::remove_filters( void )
         if( tag != NULL )
         {
             Diary::d->set_filter_tag( NULL );
-            Lifeobase::base->update_tag_icon( tag );
-            Lifeobase::base->update_button_filter_tag();
+            Lifeobase::panel_tag->update_tag_icon( tag );
+            Lifeobase::view_tag->update_button_filter_tag();
         }
         m_button_remove_filters->set_visible( false );
 
@@ -456,10 +602,10 @@ PanelDiary::handle_calendar_dayselected( void )
             Diary::d->get_current_chapter_ctg()->get_chapter( date ) == NULL );
 
 	Entry *entry;
-	if( date.m_date == ( Lifeobase::base->get_cur_elem()->get_date().get_pure() ) )
+	if( date.m_date == ( Lifeobase::panel_main->get_cur_elem()->get_date().get_pure() ) )
 	{
         entry = Diary::d->get_entry_next_in_day(
-                Lifeobase::base->get_cur_elem()->get_date() );
+                Lifeobase::panel_main->get_cur_elem()->get_date() );
 	}
 	else
 	{
@@ -481,6 +627,9 @@ PanelDiary::handle_calendar_monthchanged( void )
 void
 PanelDiary::handle_add_entry( void )
 {
+    if( Diary::d->is_read_only() )
+        return;
+
     guint year, month, day;
     m_calendar->get_date( year, month, day );
 
@@ -504,8 +653,9 @@ void
 PanelDiary::handle_add_topic( void )
 {
     Chapter *c( Diary::d->add_topic( _( "New topic" ) ) );
-    Lifeobase::base->update_entry_list();
+    update_entry_list();
     c->show();
+    Lifeobase::panel_main->start_title_edit();
 }
 
 void
@@ -520,8 +670,9 @@ PanelDiary::handle_add_chapter( void )
         Chapter *c( Diary::d->get_current_chapter_ctg()->create_chapter(
                 _( "Untitled chapter" ), date ) );
 
-        Lifeobase::base->update_entry_list();
+        update_entry_list();
         c->show();
+        Lifeobase::panel_main->start_title_edit();
     }
 }
 
@@ -551,7 +702,7 @@ PanelDiary::go_prev_match( void )
 		return;
 
 	// TODO: move to Entry
-	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::ET_ENTRY )
+	if( Lifeobase::panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
 		if( TextviewDiary::m_buffer->select_searchstr_previous() )
 			return;
 
@@ -575,7 +726,7 @@ PanelDiary::go_next_match( void )
 		return;
 
 	// TODO: move to Entry
-	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::ET_ENTRY )
+	if( Lifeobase::panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
 		if( TextviewDiary::m_buffer->select_searchstr_next() )
 			return;
 
@@ -605,17 +756,26 @@ PanelDiary::replace_match( void )
 void
 PanelDiary::replace_all_matches( void )
 {
-	Lifeobase::base->sync_entry();
+	Lifeobase::view_entry->sync();
 
 	Diary::d->replace_text( m_entry_replace->get_text() );
 	// update current entry:
-	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::ET_ENTRY )
+	if( Lifeobase::panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
 	{
-		Entry *entry = dynamic_cast< Entry* >( Lifeobase::base->get_cur_elem() );
+		Entry *entry = dynamic_cast< Entry* >( Lifeobase::panel_main->get_cur_elem() );
 		TextviewDiary::m_buffer->set_richtext( entry );
 	}
 }
 
+void
+PanelDiary::handle_entry_title_changed( DiaryElement *element )
+{
+    if( Lifeobase::m_internaloperation ) return;
+
+    Gtk::TreeRow row = * get_row( element->m_list_data->treepath );
+    row[ ListData::colrec->info ] = element->get_list_str();
+}
+
 Gtk::TreeRow
 PanelDiary::get_row( const Gtk::TreePath &path )
 {
