@@ -20,8 +20,8 @@
 ***********************************************************************************/
 
 
-#include "printing.hpp"
 #include "lifeobase.hpp"
+#include "printing.hpp"
 #include "diary.hpp"
 
 
@@ -45,10 +45,10 @@ PrintOpr::~PrintOpr()
 void
 PrintOpr::set_entry( void )
 {
-    if( Lifeobase::base->get_cur_elem_type() != DiaryElement::ET_ENTRY )
+    if( Lifeobase::panel_main->get_cur_elem_type() != DiaryElement::ET_ENTRY )
         throw LIFEO::Error( "Current element is not an entry. Printing aborted." );
 
-    Entry *entry( dynamic_cast< Entry* >( Lifeobase::base->get_cur_elem() ) );
+    Entry *entry( dynamic_cast< Entry* >( Lifeobase::panel_main->get_cur_elem() ) );
     m_parser.parse( entry );
     m_marked_up_text = Glib::ustring::compose( "<b>%1</b>\n%2",
             entry->get_date().format_string(),
@@ -125,8 +125,8 @@ PrintOpr::set_show_comments( bool flag_show )
 Gtk::Widget*
 PrintOpr::on_create_custom_widget( void )
 {
-    Gtk::HBox *hbox_main( new Gtk::HBox );
-    Gtk::VBox *vbox_extent( Gtk::manage( new Gtk::VBox ) );
+    Gtk::Box *hbox_main( new Gtk::Box );
+    Gtk::Box *vbox_extent( Gtk::manage( new Gtk::Box( Gtk::ORIENTATION_VERTICAL, 5 ) ) );
     Gtk::RadioButtonGroup rgroup_extent;
     m_rbutton_entry = ( Gtk::manage(
             new Gtk::RadioButton( rgroup_extent, _( "Only Current Entry" ) ) ) );
@@ -136,7 +136,7 @@ PrintOpr::on_create_custom_widget( void )
             new Gtk::RadioButton( rgroup_extent, _( "Entire Diary" ) ) ) );
     Gtk::Frame *frame_extent( create_frame( _( "What to Print?" ), *vbox_extent ) );
 
-    Gtk::VBox *vbox_font( Gtk::manage( new Gtk::VBox ) );
+    Gtk::Box *vbox_font( Gtk::manage( new Gtk::Box( Gtk::ORIENTATION_VERTICAL, 5 ) ) );
     m_fontbutton = Gtk::manage( new Gtk::FontButton( ThemeSystem::get()->font.to_string() ) );
     m_check_use_entry_font = Gtk::manage(
             new Gtk::CheckButton( _( "Use Theme Fonts in Entries" ) ) );
@@ -146,14 +146,12 @@ PrintOpr::on_create_custom_widget( void )
     hbox_main->set_homogeneous( true );
 
     vbox_extent->set_border_width( 5 );
-    vbox_extent->set_spacing( 5 );
     vbox_extent->pack_start( *m_rbutton_entry, Gtk::PACK_SHRINK );
     vbox_extent->pack_start( *m_rbutton_filtered, Gtk::PACK_SHRINK );
     vbox_extent->pack_start( *m_rbutton_diary, Gtk::PACK_SHRINK );
     hbox_main->pack_start( *frame_extent );
 
     vbox_font->set_border_width( 5 );
-    vbox_font->set_spacing( 5 );
     vbox_font->pack_start( *m_fontbutton, Gtk::PACK_SHRINK );
     vbox_font->pack_start( *m_check_use_entry_font, Gtk::PACK_SHRINK );
     hbox_main->pack_start( *frame_font );
