@@ -31,7 +31,7 @@ using namespace LIFEO;
 
 Settings::Settings( void )
 :	autologout( true ), idletime( IDLETIME_DEFAULT ), show_formatting_toolbar( true ),
-	width( WIDTH_DEFAULT ), height( HEIGHT_DEFAULT ),
+	diary_extension( EXTENSION_DEFAULT ), width( WIDTH_DEFAULT ), height( HEIGHT_DEFAULT ),
 	position_x( POSITION_NOTSET ), position_y( POSITION_NOTSET ),
 	position_pane( PANEPOS_DEFAULT ), position_pane_tags( PANEPOS_TAGS_DEFAULT )
 {
@@ -49,18 +49,20 @@ Settings::read( void )
 		print_info( "No configuration file, maiden voyage!" );
 		return false;
 	}
-	
+
 	reset();
 
 	std::string line;
 
 	while( getline( file, line ) )
 	{
+	    if( line.size() < 3 )
+	        continue;
+
 		switch( line[ 0 ] )
 		{
 			case 'R':
-				if( recentfiles.size() < LIFEO::MAX_RECENT_FILE_COUNT )
-					recentfiles.push_back( line.substr( 2 ) );
+				recentfiles.insert( line.substr( 2 ) );
 				break;
 
 			// TODO: position & size settings may go to the diary
@@ -97,12 +99,18 @@ Settings::read( void )
 			case 'F':
 				show_formatting_toolbar = ( line[ 2 ] == 'y' || line[ 2 ] == 'Y' );
 				break;
+			case 'E':
+			    // if only a dot (.) no extension will be added automatically
+                diary_extension = line.substr( 2 );
+                if( diary_extension[ 0 ] != '.' )
+                    diary_extension.insert( 0, "." );
+                break;
 
 			case 0:		// empty line
 			case '#':	// comment
 				break;
 			default:
-				print_info( "unrecognized line:\n" + line );
+				print_info( "unrecognized option:\n" + line );
 				break;
 		}
 	}
@@ -129,7 +137,7 @@ Settings::write( void )
 	file << "\np " << position_pane_tags;
 
 	// RECENT FILES
-	for( std::list< std::string >::iterator iter = recentfiles.begin();
+	for( ListPaths::iterator iter = recentfiles.begin();
 		 iter != recentfiles.end(); ++iter )
 		file << "\nR " << *iter;
 
@@ -137,6 +145,9 @@ Settings::write( void )
 	file << "\nI " << idletime;
 	file << "\nF " << ( show_formatting_toolbar ? 'y' : 'n' );
 
+    if( diary_extension != EXTENSION_DEFAULT )
+        file << "\nE " << diary_extension;
+
 	file.close();
 	return true;
 }
@@ -144,6 +155,19 @@ Settings::write( void )
 void
 Settings::reset( void )
 {
-	recentfiles.clear();
+    recentfiles.clear();
+    autologout = true;
+    idletime = IDLETIME_DEFAULT;
+    show_formatting_toolbar = true;
+    diary_extension = EXTENSION_DEFAULT;
 }
 
+// maybe later:
+//bool
+//Settings::get_bool_opt( int i )
+//{
+//    if( i >= m_bool_opts.size() )
+//        throw LIFEO::Error( "Requested option is out of bounds" );
+//    else
+//        return m_bool_opts[ i ];
+//}
