@@ -24,6 +24,7 @@
 #include <config.h>
 #endif
 
+#include "lifeobase.hpp"
 #include "view_entry.hpp"
 #include "printing.hpp"
 
@@ -31,8 +32,11 @@
 using namespace LIFEO;
 
 
+EntryView *Lifeobase::view_entry = NULL;
+
+
 EntryView::EntryView( void )
-:	m_menu_tag( NULL ), m_tag_operation_cur( TO_NONE ), m_ptr2entry( NULL ),
+:	m_menu_tag( NULL ), m_tag_operation_cur( TO_NONE ), m_ptr2entry( NULL ), m_entry_sync( NULL ),
 	m_flag_entrychanged( false )
 {
 	Entry::shower = this;
@@ -40,15 +44,18 @@ EntryView::EntryView( void )
 	Gtk::MenuItem *mnitem_hide( NULL );
 	Gtk::MenuItem *mnitem_hide_before( NULL );
 	Gtk::MenuItem *mnitem_hide_after( NULL );
+    Gtk::MenuItem *mnitem_tag_remove( NULL );
 
 	try
 	{
-		Lifeobase::builder->get_widget( "vbox_entry", m_vbox_entry );
+		Lifeobase::builder->get_widget( "vbox_entry", m_vbox );
         Menubutton::s_builder_name = "menubutton_entry_filter";
         Lifeobase::builder->get_widget_derived( "menubutton_entry_filter", mnbutton_filter );
         Lifeobase::builder->get_widget( "menuitem_entry_filter", mnitem_hide );
         Lifeobase::builder->get_widget( "menuitem_entry_filter_before", mnitem_hide_before );
         Lifeobase::builder->get_widget( "menuitem_entry_filter_after", mnitem_hide_after );
+        Lifeobase::builder->get_widget( "menu_entry_tags", m_menu_tag );
+        Lifeobase::builder->get_widget( "menuitem_entry_tags_remove", mnitem_tag_remove );
 		Lifeobase::builder->get_widget( "button_entry_print", m_button_print );
 		Lifeobase::builder->get_widget( "togglebutton_entry_favorite", m_button_toggle_favorite );
 		Lifeobase::builder->get_widget( "button_entry_reset_theme", m_button_reset_theme );
@@ -66,7 +73,7 @@ EntryView::EntryView( void )
 		Lifeobase::builder->get_widget_derived( "entry_tag_filter", m_tag_widget );
 		Lifeobase::builder->get_widget( "button_tag_operation", m_button_tag_operation );
 		Lifeobase::builder->get_widget( "iconview_current_tags", m_iconview_tags );
-		Lifeobase::builder->get_widget( "alignment_entry_toolbar", m_alignment_toolbar );
+		Lifeobase::builder->get_widget( "box_entry_toolbar", m_box_toolbar );
 		Lifeobase::builder->get_widget( "hbox_entry_toolbar_text", m_hbox_editing_toolbar );
 	}
 	catch( ... ) {}
@@ -78,19 +85,19 @@ EntryView::EntryView( void )
 
 	// TAG LIST
 	m_liststore_tags = Gtk::ListStore::create( *TagPanel::colrec );
+	m_iconview_tags->set_model( m_liststore_tags );
 	m_iconview_tags->set_pixbuf_column( TagPanel::colrec->icon );
 	m_iconview_tags->set_markup_column( TagPanel::colrec->name );
-	m_iconview_tags->set_model( m_liststore_tags );
-	m_iconview_tags->set_orientation( Gtk::ORIENTATION_HORIZONTAL );
-	m_iconview_tags->set_selection_mode( Gtk::SELECTION_MULTIPLE );
-	m_iconview_tags->set_events( Gdk::ENTER_NOTIFY_MASK );
-	m_iconview_tags->set_item_width( 150 );
+	//m_iconview_tags->set_events( Gdk::ENTER_NOTIFY_MASK );
 	m_iconview_tags->drag_dest_set( Lifeobase::base->drag_targets_tag );
-	m_iconview_tags->modify_base(
-			Gtk::STATE_NORMAL, Lifeobase::base->get_style()->get_bg( Gtk::STATE_NORMAL ) );
-
-	// TOOLBAR
-	m_hbox_editing_toolbar->set_visible( Lifeobase::m_settings.show_formatting_toolbar );
+	Gdk::RGBA bgc;
+	bgc.set_alpha( 0.0 );
+	m_iconview_tags->override_background_color(
+			bgc, //Lifeobase::base->get_style_context()->get_background_color( Gtk::STATE_FLAG_NORMAL ),
+			Gtk::STATE_FLAG_NORMAL );
+	m_iconview_tags->override_background_color(
+	        Lifeobase::base->get_style_context()->get_background_color( Gtk::STATE_FLAG_SELECTED ),
+	        Gtk::STATE_FLAG_SELECTED );
 
 	// SIGNALS
 	TextviewDiary::m_buffer->signal_changed().connect(
@@ -110,6 +117,9 @@ EntryView::EntryView( void )
     mnitem_hide_after->signal_activate().connect(
             sigc::mem_fun( this, &EntryView::hide_after ) );
 
+    mnitem_tag_remove->signal_activate().connect(
+            sigc::mem_fun( this, &EntryView::remove_selected_tags ) );
+
 	m_button_bold->signal_clicked().connect(
 			sigc::mem_fun( m_textviewdiary->m_buffer, &TextbufferDiary::toggle_bold ) );
 	m_button_italic->signal_clicked().connect(
@@ -125,7 +135,7 @@ EntryView::EntryView( void )
 			sigc::mem_fun( m_textviewdiary->m_buffer, &TextbufferDiary::add_checkbox ) );
 
     m_button_toggle_comments->signal_clicked().connect(
-            sigc::mem_fun( this, &EntryView::toggle_comments ) );
+            sigc::mem_fun( this, &EntryView::handle_comments_toggled ) );
 
 	m_textviewdiary->signal_drag_data_received().connect(
 			sigc::mem_fun( this, &EntryView::handle_drag_data_received ) );
@@ -158,7 +168,8 @@ EntryView::populate_tags( void )
 	if( ptr2tagset.size() < 1 )
 	{
 		row = * m_liststore_tags->append();
-		row[ TagPanel::colrec->name ] = Glib::ustring::compose( "<i>%1</i>", _( "Not tagged" ) );
+		row[ TagPanel::colrec->name ] = Glib::ustring::compose(
+		        "<small><i>%1</i></small>", _( "Not tagged" ) );
 		row[ TagPanel::colrec->ptr ] = NULL;
 		return;
 	}
@@ -186,8 +197,8 @@ EntryView::sync( void )
 {
 	if( m_flag_entrychanged )
 	{
-		m_ptr2entry->m_date_changed = time( NULL );
-		m_ptr2entry->m_text = TextviewDiary::m_buffer->get_text();
+		m_entry_sync->m_date_changed = time( NULL );
+		m_entry_sync->m_text = TextviewDiary::m_buffer->get_text();
 		m_flag_entrychanged = false;
 		PRINT_DEBUG( "entry synced" );
 	}
@@ -203,9 +214,9 @@ EntryView::focus_tag( void )
 void
 EntryView::remove_selected_tags( void )
 {
-	std::list< Gtk::TreeModel::Path > selected_items =
+	std::vector< Gtk::TreeModel::Path > selected_items =
 			m_iconview_tags->get_selected_items();
-	for( std::list< Gtk::TreeModel::Path >::iterator iter = selected_items.begin();
+	for( std::vector< Gtk::TreeModel::Path >::iterator iter = selected_items.begin();
 		 iter != selected_items.end();
 		 ++iter )
 	{
@@ -231,6 +242,12 @@ void
 EntryView::handle_login( void )
 {
 	m_textviewdiary->m_buffer->handle_login();
+
+    // READ ONLY
+    bool editable( ! Diary::d->is_read_only() );
+    m_textviewdiary->set_editable( editable );
+    m_tag_widget->set_visible( editable );
+    update_formatting_toolbar();
 }
 
 void
@@ -255,6 +272,9 @@ EntryView::handle_drag_data_received(
 				uint info,
 				guint time )
 {
+    if( Diary::d->is_read_only() )
+        return;
+
 	context->drag_finish( true, false, time );
 
 	Glib::ustring name = selection_data.get_data_as_string();
@@ -273,6 +293,9 @@ EntryView::handle_drag_data_received(
 		}
 		case DRAG_TARGET_THEME_INFO:
 		{
+            // system theme added back to m_themes:
+//		    Theme *theme = ( name == STRING::SYSTEM_THEME ) ? ThemeSystem::get() :
+//                Diary::d->m_themes.find( name )->second;
 			Theme *theme = Diary::d->m_themes.find( name )->second;
 			m_ptr2entry->set_theme( theme );
 			TextviewDiary::m_buffer->set_theme( theme );
@@ -282,7 +305,7 @@ EntryView::handle_drag_data_received(
 		}
 		case DRAG_TARGET_ENTRY_INFO:
 		{
-			DiaryElement *element = Lifeobase::base->get_dragged_elem();
+			DiaryElement *element = Lifeobase::panel_diary->get_dragged_elem();
 			if( element != NULL )
                 if( element->get_type() == DiaryElement::ET_ENTRY )
                     TextviewDiary::m_buffer->insert_link( element );
@@ -305,7 +328,7 @@ EntryView::toggle_favoredness( void )
 void
 EntryView::print( void )
 {
-    Lifeobase::base->sync_entry();
+    Lifeobase::view_entry->sync();
 
     Glib::RefPtr< PrintOpr > print = PrintOpr::create();
 
@@ -327,25 +350,24 @@ EntryView::hide( void )
 {
     m_ptr2entry->m_flag_filteredout = true;
     Diary::d->activate_individual_filter();
-    Lifeobase::base->update_button_remove_filters();
-    Lifeobase::base->update_entry_list();
+    Lifeobase::panel_diary->update_button_remove_filters();
+    Lifeobase::panel_diary->update_entry_list();
 }
 
-
 void
 EntryView::hide_before( void )
 {
     Diary::d->set_filter_date_begin( m_ptr2entry->get_date().m_date );
-    Lifeobase::base->update_button_remove_filters();
-    Lifeobase::base->update_entry_list();
+    Lifeobase::panel_diary->update_button_remove_filters();
+    Lifeobase::panel_diary->update_entry_list();
 }
 
 void
 EntryView::hide_after( void )
 {
     Diary::d->set_filter_date_end( m_ptr2entry->get_date().m_date );
-    Lifeobase::base->update_button_remove_filters();
-    Lifeobase::base->update_entry_list();
+    Lifeobase::panel_diary->update_button_remove_filters();
+    Lifeobase::panel_diary->update_entry_list();
 }
 
 void
@@ -367,23 +389,63 @@ EntryView::dismiss_entry( void )
     // ...else dark forces may take action and cause SEGFAULT:
     Diary::d->show();
 
-	Lifeobase::base->remove_element_from_history( m_ptr2entry );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2entry );
 	Diary::d->dismiss_entry( m_ptr2entry );
 
 	Lifeobase::m_internaloperation++;
 
-	Lifeobase::base->update_calendar();
-	Lifeobase::base->update_entry_list();
+	Lifeobase::panel_diary->update_calendar();
+	Lifeobase::panel_diary->update_entry_list();
 
 	Lifeobase::m_internaloperation--;
 }
 
 void
-EntryView::toggle_comments( void )
+EntryView::handle_comments_toggled( void )
 {
     m_textviewdiary->m_buffer->show_comments( m_button_toggle_comments->get_active() );
 }
 
+void
+EntryView::toggle_comments( void )
+{
+    m_button_toggle_comments->set_active( ! m_button_toggle_comments->get_active() );
+}
+
+bool
+EntryView::check_title_applicable( const Glib::ustring &str ) const
+{
+    try
+    {
+        Date date( str );
+    }
+    catch( LIFEO::Error &er )
+    {
+        return false;
+    }
+
+    return true;
+}
+
+bool
+EntryView::apply_title( const Glib::ustring &str )
+{
+    try
+    {
+        Date date( str );
+        date.reset_order_1();
+        Diary::d->set_entry_date( m_ptr2entry, date );
+        Lifeobase::panel_diary->update_entry_list();
+        Lifeobase::panel_diary->select_date_in_calendar( m_ptr2entry->get_date() );
+    }
+    catch( LIFEO::Error &er )
+    {
+        return false;
+    }
+
+    return true;
+}
+
 void
 EntryView::handle_entry_tag_changed( void )
 {
@@ -436,7 +498,7 @@ EntryView::handle_button_tag_clicked( void )
 		case TO_CREATE_AND_ADD:
 			tag = Diary::d->create_tag( filter );
 			m_ptr2entry->add_tag( tag );
-			Lifeobase::base->update_tag_list();
+			Lifeobase::panel_tag->populate_main();
             m_tag_widget->populate();
 			break;
 		case TO_ADD:
@@ -452,11 +514,10 @@ EntryView::handle_button_tag_clicked( void )
 void
 EntryView::handle_iconview_tags_key_release( GdkEventKey *event )
 {
-	if( event->keyval != GDK_Delete )	// the cheapest check first
+	if( event->keyval != GDK_KEY_Delete || Diary::d->is_read_only() )	// the cheapest check first
 		return;
 
-	std::list< Gtk::TreeModel::Path > selected_items =
-			m_iconview_tags->get_selected_items();
+	std::vector< Gtk::TreeModel::Path > selected_items = m_iconview_tags->get_selected_items();
 
 	if( selected_items.empty() )
 		return;
@@ -471,10 +532,10 @@ EntryView::handle_iconview_tags_key_release( GdkEventKey *event )
 void
 EntryView::handle_iconview_tags_button_press( GdkEventButton *event )
 {
-	if( event->button != 3 )
+	if( event->button != 3 || Diary::d->is_read_only() )
 		return;
 
-	std::list< Gtk::TreeModel::Path > selected_items =
+	std::vector< Gtk::TreeModel::Path > selected_items =
 			m_iconview_tags->get_selected_items();
 
 	if( selected_items.empty() )
@@ -484,55 +545,26 @@ EntryView::handle_iconview_tags_button_press( GdkEventButton *event )
 				TagPanel::colrec->ptr ) == NULL )
 		return;
 
-	if( m_menu_tag )
-	{
-		delete m_menu_tag;
-		m_menu_tag = NULL;
-	}
-
-	m_menu_tag = new Gtk::Menu;
-	Gtk::Image *image_remove = Gtk::manage(
-		new Gtk::Image( Gtk::Stock::REMOVE, Gtk::ICON_SIZE_MENU ) );
-
-	m_menu_tag->items().push_back(
-			// TRANSLATORS: label of the remove-selected-tags-from-current-entry
-			// menu item
-			Gtk::Menu_Helpers::ImageMenuElem( _( "_Remove from Entry" ), *image_remove,
-					sigc::mem_fun( *this, &EntryView::remove_selected_tags ) ) );
-
-	m_menu_tag->accelerate( *Lifeobase::base );
 	m_menu_tag->popup( event->button, event->time );
 }
 
 void
 EntryView::show( Entry &entry )
 {
-	// do nothing is entry is already the current element:
-	if( ! Lifeobase::base->change_current_element( &entry, m_vbox_entry ) )
+	// do nothing if entry is already the current element:
+	if( Lifeobase::panel_main->is_cur_elem( &entry ) )
 		return;
 
-	m_ptr2entry = &entry;
+	m_ptr2entry = &entry; // must be first thing
 
-	// HEADER
-	Lifeobase::m_image_gui_elem->set( Lifeobase::icons->entry_32 );
-	Lifeobase::base->set_header_texts(
-			entry.m_date.format_string(),
-			entry.m_date.is_ordinal() ? Date::format_string_do( &entry.m_date_created )
-					: entry.m_date.get_weekday_str(),
-			Glib::ustring::compose( "%1: <b>%2</b>\n%3: <b>%4</b>\nDEID:%5",
-// TRANSLATORS: label of creation date
-									_( "Created"), entry.get_date_created_str(),
-// TRANSLATORS: label of last change date
-									_( "Changed"), entry.get_date_changed_str(),
-									entry.m_id ) );
-
-	Lifeobase::set_gelem_toolbar( m_alignment_toolbar );
+	Lifeobase::panel_main->show( this );
 
 	// TOOLBAR
 	update_highlight_button();
 
-	Lifeobase::m_internaloperation++;
 	// BODY
+	Lifeobase::m_internaloperation++;
+
 	m_textviewdiary->set_richtext( &entry );
 	populate_tags();
 	m_button_toggle_favorite->set_active( entry.m_option_favored );
@@ -542,6 +574,8 @@ EntryView::show( Entry &entry )
 
     m_tag_widget->populate();
 
+    m_entry_sync = m_ptr2entry;
+
 	PRINT_DEBUG( "entry shown" );
 }
 
@@ -552,10 +586,18 @@ EntryView::prepare_for_hiding( Entry &entry )
 	m_tag_widget->set_text( "" );
 }
 
+Glib::RefPtr< Gdk::Pixbuf >&
+EntryView::get_icon_32( void ) const
+{
+    return( // TODO: m_option_favored ? Lifeobase::icons->entry_favorite_32 :
+            Lifeobase::icons->entry_32 );
+}
+
 void
 EntryView::update_formatting_toolbar( void )
 {
-	m_hbox_editing_toolbar->set_visible( Lifeobase::m_settings.show_formatting_toolbar );
+	m_hbox_editing_toolbar->set_visible( Lifeobase::settings.show_formatting_toolbar &&
+	                                     Diary::d->is_read_only() == false );
 }
 
 void
@@ -563,10 +605,13 @@ EntryView::update_highlight_button( void )
 {
 	const Theme *theme = m_ptr2entry->get_theme_is_set() ?
 			m_ptr2entry->get_theme() : Diary::d->get_default_theme();
-	m_label_highlight->modify_fg( Gtk::STATE_NORMAL, theme->color_text );
-	m_label_highlight->modify_fg( Gtk::STATE_PRELIGHT, theme->color_text );
-	m_label_highlight->modify_fg( Gtk::STATE_ACTIVE, theme->color_text );
-	m_eventbox_highlight->modify_bg( Gtk::STATE_NORMAL, theme->color_highlight );
-	m_eventbox_highlight->modify_bg( Gtk::STATE_PRELIGHT, theme->color_highlight );
-	m_eventbox_highlight->modify_bg( Gtk::STATE_ACTIVE, theme->color_highlight );
+	m_label_highlight->override_color( theme->color_text, Gtk::STATE_FLAG_NORMAL );
+	m_label_highlight->override_color( theme->color_text, Gtk::STATE_FLAG_PRELIGHT );
+	m_label_highlight->override_color( theme->color_text, Gtk::STATE_FLAG_ACTIVE );
+	m_eventbox_highlight->override_background_color(
+	        theme->color_highlight, Gtk::STATE_FLAG_NORMAL );
+	m_eventbox_highlight->override_background_color(
+	        theme->color_highlight, Gtk::STATE_FLAG_PRELIGHT );
+	m_eventbox_highlight->override_background_color(
+	        theme->color_highlight, Gtk::STATE_FLAG_ACTIVE );
 }
