@@ -35,18 +35,17 @@
 using namespace LIFEO;
 
 
-// TAG =========================================================================
+// TAG =============================================================================================
+TagView *Lifeobase::view_tag = NULL;
+
 TagView::TagView( void )
 {
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_tag", m_vbox );
-		Lifeobase::builder->get_widget( "alignment_tag_toolbar", m_alignment_toolbar );
+		Lifeobase::builder->get_widget( "box_tag_toolbar", m_box_toolbar );
 		Lifeobase::builder->get_widget( "togglebutton_tag_filter", m_button_filter );
 		Lifeobase::builder->get_widget( "button_tag_dismiss", m_button_dismiss );
-		Lifeobase::builder->get_widget( "entry_tag_name", m_entry_name );
-		Lifeobase::builder->get_widget( "button_tag_name_apply", m_button_name_apply );
-		//Lifeobase::builder->get_widget( "label_tag_period", m_label_period );
 		Lifeobase::builder->get_widget( "combobox_tag_category", m_combobox_category );
 		Lifeobase::builder->get_widget_derived( "drawingarea_tag_chart", m_widgetchart );
 
@@ -67,52 +66,49 @@ TagView::TagView( void )
 	m_button_dismiss->signal_clicked().connect(
 			sigc::mem_fun( this, &TagView::dismiss_tag ) );
 
-	m_button_name_apply->signal_clicked().connect(
-			sigc::mem_fun( this, &TagView::handle_name_applied ) );
-	m_entry_name->signal_changed().connect(
-			sigc::mem_fun( this, &TagView::handle_name_changed ) );
-	m_entry_name->signal_activate().connect(
-			sigc::mem_fun( *m_button_name_apply, &Gtk::Button::clicked ) );
-
 	m_combobox_category->signal_changed().connect(
 			sigc::mem_fun( this, &TagView::handle_category_changed ) );
 }
 
+bool
+TagView::check_title_applicable( const Glib::ustring &name ) const
+{
+	Tag *tag = Diary::d->get_tags()->get_tag( name );
+	return( !( tag || name.empty() ) );
+}
+
+bool
+TagView::apply_title( const Glib::ustring &name )
+{
+	// a caution against calls by an entry activation event:
+	if( ! check_title_applicable( name ) )
+		return false;
+
+	Diary::d->get_tags()->rename( m_ptr2tag, name );
+	Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2tag );
+	row[ TagPanel::colrec->name ] = Glib::Markup::escape_text( name );
+
+	return true;
+}
+
+void
+TagView::handle_login( void )
+{
+    update_combobox_categories();
+    m_combobox_category->set_sensitive( ! Diary::d->is_read_only() );
+}
+
 void
 TagView::handle_filter_toggled( void )
 {
-	if( Lifeobase::m_internaloperation )
-		return;
+    if( Lifeobase::m_internaloperation )
+        return;
 
-	Diary::d->set_filter_tag( m_button_filter->get_active() ? m_ptr2tag : NULL );
-    Lifeobase::base->update_button_filter_tag();
-    Lifeobase::base->update_button_remove_filters();
-    Lifeobase::base->update_tag_icon( m_ptr2tag );
-    Lifeobase::base->update_entry_list();
-}
-
-void
-TagView::handle_name_changed( void )
-{
-	Glib::ustring name = m_entry_name->get_text();
-	Tag *tag = Diary::d->get_tags()->get_tag( name );
-	m_button_name_apply->set_sensitive( !( tag || name.empty() ) );
-}
-
-void
-TagView::handle_name_applied( void )
-{
-	// a caution against calls by an entry activation event:
-	if( ! m_button_name_apply->is_sensitive() )
-		return;
-	Glib::ustring name = m_entry_name->get_text();
-	Diary::d->get_tags()->rename( m_ptr2tag, name );
-	Lifeobase::base->m_label_gui_elem->set_label( name );
-
-	m_button_name_apply->set_sensitive( false );
-
-	Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2tag );
-	row[ TagPanel::colrec->name ] = Glib::Markup::escape_text( name );
+    Diary::d->set_filter_tag( m_button_filter->get_active() ? m_ptr2tag : NULL );
+    update_button_filter_tag();
+    Lifeobase::panel_diary->update_button_remove_filters();
+    Lifeobase::panel_tag->update_tag_icon( m_ptr2tag );
+    Lifeobase::panel_diary->update_entry_list();
 }
 
 void
@@ -130,13 +126,14 @@ TagView::handle_category_changed( void )
 			CategoryTags *category = Diary::d->create_tag_ctg();
 			m_ptr2tag->set_category( category );
 			update_combobox_categories();
-			Lifeobase::base->update_tag_list();
+			Lifeobase::panel_tag->populate_main();
 			category->show();
+			Lifeobase::panel_main->start_title_edit();
 		}
 		else	// assign a category or reset
 		{
 			m_ptr2tag->set_category( row[ colrec_category.ptr ] );
-			Lifeobase::base->update_tag_list();
+			Lifeobase::panel_tag->populate_main();
 		}
 	}
 }
@@ -184,28 +181,30 @@ TagView::update_combobox_categories( void )
 	row[ colrec_category.type ] = TCT_NEW;
 }
 
+void
+TagView::update_button_filter_tag( void )
+{
+    Lifeobase::m_internaloperation++;
+    m_button_filter->set_active( Diary::d->get_filter_tag() != NULL );
+    Lifeobase::m_internaloperation--;
+}
+
 void
 TagView::show( Tag &tag )
 {
 	// do nothing is entry is already the current element:
-	if( ! Lifeobase::base->change_current_element( &tag, m_vbox ) )
-		return;
+    if( Lifeobase::panel_main->is_cur_elem( &tag ) )
+        return;
 
 	m_ptr2tag = &tag;
 
+    Lifeobase::panel_main->show( this );
+
 	Lifeobase::m_internaloperation++;
-	// HEADER
-	Lifeobase::m_image_gui_elem->set( Lifeobase::icons->tag_32 );
-	Lifeobase::base->set_header_texts(
-			tag.m_name,
-			Glib::ustring::compose( _( "%1 entries" ), tag.m_items.size() ) );
-	Lifeobase::set_gelem_toolbar( m_alignment_toolbar );
 
 	// BODY
 	m_button_filter->set_active( Diary::d->get_filter_tag() == &tag );
 
-	m_entry_name->set_text( tag.m_name );
-
 	for( Gtk::TreeIter iter = m_liststore_categories->children().begin();
 		 iter != m_liststore_categories->children().end();
 		 ++iter )
@@ -253,6 +252,12 @@ TagView::show( Tag &tag )
 	Lifeobase::m_internaloperation--;
 }
 
+Glib::RefPtr< Gdk::Pixbuf >&
+TagView::get_icon_32( void ) const
+{
+    return Lifeobase::icons->tag_32;
+}
+
 void
 TagView::dismiss_tag( void )
 {
@@ -261,17 +266,17 @@ TagView::dismiss_tag( void )
 
     Diary::d->show();
 
-	Lifeobase::base->remove_element_from_history( m_ptr2tag );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2tag );
 
 	// clear filter if necessary:
 	if( Diary::d->get_filter_tag() == m_ptr2tag )
 	{
 		Diary::d->set_filter_tag( NULL );
-        Lifeobase::base->update_button_remove_filters();
-        Lifeobase::base->update_entry_list();
+        Lifeobase::panel_diary->update_button_remove_filters();
+        Lifeobase::panel_diary->update_entry_list();
 	}
 	Diary::d->dismiss_tag( m_ptr2tag );
-	Lifeobase::base->update_tag_list();
+	Lifeobase::panel_tag->populate_main();
 }
 
 bool
@@ -290,22 +295,11 @@ CategoryTagsView::CategoryTagsView( void )
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_categorytags", m_vbox );
-		Lifeobase::builder->get_widget( "alignment_categorytags_toolbar", m_alignment_toolbar );
-		Lifeobase::builder->get_widget( "entry_categorytags_name", m_entry_name );
-		Lifeobase::builder->get_widget( "button_categorytags_name_apply", m_button_name_apply );
-		Lifeobase::builder->get_widget( "button_categorytags_dismiss", m_button_dismiss );
+		Lifeobase::builder->get_widget( "box_ctg_tags_toolbar", m_box_toolbar );
+		Lifeobase::builder->get_widget( "button_ctg_tags_dismiss", m_button_dismiss );
 	}
 	catch( ... ) {}
 
-	m_entry_name->signal_changed().connect(
-			sigc::mem_fun( this, &CategoryTagsView::handle_name_changed ) );
-
-	m_entry_name->signal_activate().connect(
-			sigc::mem_fun( *m_button_name_apply, &Gtk::Button::clicked ) );
-
-	m_button_name_apply->signal_clicked().connect(
-			sigc::mem_fun( this, &CategoryTagsView::handle_name_applied ) );
-
 	m_button_dismiss->signal_clicked().connect(
 			sigc::mem_fun( this, &CategoryTagsView::dismiss_category ) );
 }
@@ -314,41 +308,38 @@ void
 CategoryTagsView::show( CategoryTags &category )
 {
 	// do nothing is entry is already the current element:
-	if( ! Lifeobase::base->change_current_element( &category, m_vbox ) )
+    if( Lifeobase::panel_main->is_cur_elem( &category ) )
 		return;
 
 	m_ptr2category = &category;
 
-	// HEADER
-	Lifeobase::m_image_gui_elem->set( Lifeobase::icons->tag_category_32 );
-	Lifeobase::base->set_header_texts(
-			category.m_name,
-			Glib::ustring::compose( _( "%1 tags" ), category.size() ) );
-	Lifeobase::set_gelem_toolbar( m_alignment_toolbar );
-
-	// BODY
-	m_entry_name->set_text( category.m_name );
+	Lifeobase::panel_main->show( this );
 }
 
-void
-CategoryTagsView::handle_name_changed( void )
+Glib::RefPtr< Gdk::Pixbuf >&
+CategoryTagsView::get_icon_32( void ) const
+{
+    return Lifeobase::icons->tag_32;
+}
+
+bool
+CategoryTagsView::check_title_applicable( const Glib::ustring &name ) const
 {
-	Glib::ustring name = m_entry_name->get_text();
 	PoolCategoriesTags::const_iterator iter = Diary::d->m_tag_categories.find( name );
-	m_button_name_apply->set_sensitive(
-			!( iter != Diary::d->m_tag_categories.end() || name.empty() ) );
+	return( iter == Diary::d->m_tag_categories.end() && name.empty() == false );
 }
 
-void
-CategoryTagsView::handle_name_applied( void )
+bool
+CategoryTagsView::apply_title( const Glib::ustring &name )
 {
-	Glib::ustring name = m_entry_name->get_text();
-	Diary::d->m_tag_categories.rename_category( m_ptr2category, name );
-	Lifeobase::base->m_label_gui_elem->set_label( name );
-	Lifeobase::base->update_tag_list();
-	Lifeobase::base->update_tag_categories();	// updates the combobox in TagView
+    if( ! check_title_applicable( name ) )
+        return false;
 
-	m_button_name_apply->set_sensitive( false );
+	Diary::d->m_tag_categories.rename_category( m_ptr2category, name );
+	Lifeobase::panel_tag->populate_main();
+	Lifeobase::view_tag->update_combobox_categories();
+
+	return true;
 }
 
 void
@@ -359,11 +350,11 @@ CategoryTagsView::dismiss_category( void )
 
     Diary::d->show();
 
-	Lifeobase::base->remove_element_from_history( m_ptr2category );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2category );
 	// TODO: offer merging with a category
 	Diary::d->dismiss_tag_ctg( m_ptr2category );
-	Lifeobase::base->update_tag_list();
-	Lifeobase::base->update_tag_categories();
+	Lifeobase::panel_tag->populate_main();
+	Lifeobase::view_tag->update_combobox_categories();
 }
 
 // CHAPTER =========================================================================================
@@ -371,51 +362,33 @@ ChapterView::ChapterView( void )
 {
 	Chapter::shower = this;
 
-	Gtk::Button		*button_new_entry;
+	Gtk::Button *button_new_entry( NULL );
 
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_chapter", m_vbox );
-		Lifeobase::builder->get_widget( "alignment_chapter_toolbar", m_alignment_toolbar );
+		Lifeobase::builder->get_widget( "box_chapter_toolbar", m_box_toolbar );
 		Lifeobase::builder->get_widget( "button_chapter_dismiss", m_button_dismiss );
-		Lifeobase::builder->get_widget( "entry_chapter_name", m_entry_name );
-		Lifeobase::builder->get_widget( "button_chapter_name_apply", m_button_name_apply );
 
-		Lifeobase::builder->get_widget( "label_chapter_period", m_label_period );
-		Lifeobase::builder->get_widget( "hbox_chapter_period", m_hbox_period );
+//		Lifeobase::builder->get_widget( "label_chapter_period", m_label_period );
+//		Lifeobase::builder->get_widget( "hbox_chapter_period", m_hbox_period );
 		Lifeobase::builder->get_widget( "entry_chapter_begins", m_entry_begins );
 		Lifeobase::builder->get_widget( "button_chapter_date_apply", m_button_date_apply );
 		Lifeobase::builder->get_widget( "label_chapter_ends", m_label_ends );
 
-		Lifeobase::builder->get_widget( "frame_chapter_actions", m_frame_actions );
+		Lifeobase::builder->get_widget( "frame_chapter_edit", m_frame_edit );
+        Lifeobase::builder->get_widget( "frame_chapter_actions", m_frame_actions );
 		Lifeobase::builder->get_widget( "button_chapter_new_entry", button_new_entry );
-
-		//m_liststore_chapter_type = Gtk::ListStore::create( colrec_chapter_type );
 	}
-	catch( ... ) {}
-
-	// TYPE
-	//m_combo_type->set_model( m_liststore_chapter_type );
-	//m_combo_type->pack_start( colrec_chapter_type.name );
-	//Gtk::TreeRow row( * m_liststore_chapter_type->append() );
-	//row[ colrec_chapter_type.name ] = _( "Time Based" );
-	//row[ colrec_chapter_type.type ] = CT_TEMPORAL;
-	//row = * m_liststore_chapter_type->append();
-	//row[ colrec_chapter_type.name ] = _( "Time Independent" );
-	//row[ colrec_chapter_type.type ] = CT_ORDINAL;
-
+	catch( ... )
+	{
+	    throw HELPERS::Error( "Chapter view could not be constructed" );
+	}
 	
 	// SIGNALS
 	m_button_dismiss->signal_clicked().connect(
 			sigc::mem_fun( this, &ChapterView::dismiss_chapter ) );
 
-	m_entry_name->signal_changed().connect(
-			sigc::mem_fun( *this, &ChapterView::handle_name_changed ) );
-	m_entry_name->signal_activate().connect(
-			sigc::mem_fun( *m_button_name_apply, &Gtk::Button::clicked ) );
-	m_button_name_apply->signal_clicked().connect(
-			sigc::mem_fun( *this, &ChapterView::handle_name_applied ) );
-
 	m_entry_begins->signal_changed().connect(
 			sigc::mem_fun( *this, &ChapterView::handle_date_changed ) );
 	m_entry_begins->signal_activate().connect(
@@ -435,31 +408,27 @@ ChapterView::dismiss_chapter( void )
 
     Diary::d->show();
 
-	Lifeobase::base->remove_element_from_history( m_ptr2chapter );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2chapter );
 	Diary::d->dismiss_chapter( m_ptr2chapter );
-	Lifeobase::base->update_entry_list();
+	Lifeobase::panel_diary->update_entry_list();
 }
 
-void
-ChapterView::handle_name_changed( void )
+bool
+ChapterView::check_title_applicable( const Glib::ustring &str ) const
 {
-	Glib::ustring name = m_entry_name->get_text();
-	m_button_name_apply->set_sensitive( ! name.empty() &&
-										name != m_ptr2chapter->m_name );
+	return( ! str.empty() && str != m_ptr2chapter->m_name );
 }
 
-void
-ChapterView::handle_name_applied( void )
+bool
+ChapterView::apply_title( const Glib::ustring &str )
 {
 	// a caution against calls by an entry activation event:
-	if( ! m_button_name_apply->is_sensitive() )
-		return;
-	Glib::ustring name = m_entry_name->get_text();
-	m_ptr2chapter->m_name = name;
-	m_button_name_apply->set_sensitive( false );
-	Lifeobase::base->m_label_gui_elem->set_label( name );
+	if( ! check_title_applicable( str ) )
+		return false;
+	m_ptr2chapter->set_name( str );
 	Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2chapter );
 	row[ ListData::colrec->info ] = m_ptr2chapter->get_list_str();
+	return true;
 }
 
 void
@@ -487,7 +456,7 @@ ChapterView::handle_date_applied( void )
 			m_ptr2chapter, Date( m_entry_begins->get_text() ) ) )
 	{
 		m_button_date_apply->set_sensitive( false );
-		Lifeobase::base->update_entry_list();
+		Lifeobase::panel_diary->update_entry_list();
 		update_labels();
 	}
 }
@@ -495,37 +464,23 @@ ChapterView::handle_date_applied( void )
 void
 ChapterView::update_labels( void )
 {
-	if( m_ptr2chapter->m_date_begin.is_ordinal() )
+	if( ! m_ptr2chapter->m_date_begin.is_ordinal() )
 	{
-		Lifeobase::base->set_header_texts(
-				Glib::ustring::compose( "%1. %2", m_ptr2chapter->get_date().format_string(),
-									    m_ptr2chapter->m_name ),
-				Glib::ustring::compose( _( "%1 entries" ), m_ptr2chapter->get_size() ) );
-	}
-	else
-	{
-		int timespan( 0 );
+        Lifeobase::m_internaloperation++;
 
 		m_entry_begins->set_text( m_ptr2chapter->m_date_begin.format_string() );
 
 		CategoryChapters::iterator iter( Diary::d->get_current_chapter_ctg()->find(
 												m_ptr2chapter->get_date().m_date ) );
-		if( iter == Diary::d->get_current_chapter_ctg()->begin() )
+		if( m_ptr2chapter->m_time_span == 0 )
 			m_label_ends->set_text( _( "Unlimited" ) );
 		else
 		{
 			--iter;
 			m_label_ends->set_text( iter->second->m_date_begin.format_string() );
-			Glib::Date gdate_begin( m_ptr2chapter->m_date_begin.get_glib() );
-			Glib::Date gdate_end( iter->second->m_date_begin.get_glib() );
-			timespan = gdate_begin.days_between( gdate_end );
 		}
 
-		Lifeobase::base->set_header_texts(
-				m_ptr2chapter->m_name,
-				Glib::ustring::compose(
-						timespan ? _( "%1 entries in %2 days" ) : _( "%1 entries" ),
-						m_ptr2chapter->get_size(), timespan ) );
+        Lifeobase::m_internaloperation--;
 	}
 }
 
@@ -534,31 +489,40 @@ ChapterView::add_new_entry( void )
 {
 	Diary::d->create_entry( m_ptr2chapter->get_free_order().m_date );
 
-	Lifeobase::base->update_entry_list();
-	Lifeobase::base->update_calendar();
+	Lifeobase::panel_diary->update_entry_list();
+	Lifeobase::panel_diary->update_calendar();
 }
 
 void
 ChapterView::show( Chapter &chapter )
 {
-	// do nothing is entry is already the current element:
-	if( ! Lifeobase::base->change_current_element( &chapter, m_vbox ) )
-		return;
+    // do nothing if entry is already the current element:
+    if( Lifeobase::panel_main->is_cur_elem( &chapter ) )
+        return;
 
 	m_ptr2chapter = &chapter;
 
-	Lifeobase::m_image_gui_elem->set( chapter.get_icon_32() );
-	Lifeobase::set_gelem_toolbar( m_alignment_toolbar );
+	Lifeobase::panel_main->show( this );
 
-	Lifeobase::m_internaloperation++;
+	// BODY
 	update_labels();
-	m_entry_name->set_text( chapter.m_name );
-	Lifeobase::m_internaloperation--;
 
-	bool flag_temporal( ! chapter.m_date_begin.is_ordinal() );
-	m_label_period->set_visible( flag_temporal );
-	m_hbox_period->set_visible( flag_temporal );
-	m_frame_actions->set_visible( ! flag_temporal );
+	bool flag_ordinal( chapter.m_date_begin.is_ordinal() );
+	//m_label_period->set_visible( flag_temporal );
+	//m_hbox_period->set_visible( flag_temporal );
+	m_frame_edit->set_visible( ! flag_ordinal );
+	m_frame_actions->set_visible( flag_ordinal );
+
+    // TODO: move to handle_login()
+	m_frame_edit->set_sensitive( ! Diary::d->is_read_only() );
+    m_frame_actions->set_sensitive( ! Diary::d->is_read_only() );
+}
+
+Glib::RefPtr< Gdk::Pixbuf >&
+ChapterView::get_icon_32( void ) const
+{
+    return m_ptr2chapter->m_date_begin.is_ordinal() ?
+                Lifeobase::icons->chapter_32 : Lifeobase::icons->month_32;
 }
 
 // THEME ===========================================================================================
@@ -569,9 +533,7 @@ ThemeView::ThemeView( void )
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_theme", m_vbox );
-		Lifeobase::builder->get_widget( "entry_theme_name", m_entry_name );
-		Lifeobase::builder->get_widget( "button_theme_name_apply", m_button_name_apply );
-		Lifeobase::builder->get_widget( "alignment_theme_toolbar", m_alignment_toolbar );
+		Lifeobase::builder->get_widget( "box_theme_toolbar", m_box_toolbar );
 		Lifeobase::builder->get_widget( "fontbutton_theme", m_fontbutton );
 		Lifeobase::builder->get_widget( "colorbutton_theme_bground", m_colorbutton_bground );
 		Lifeobase::builder->get_widget( "colorbutton_theme_text", m_colorbutton_text );
@@ -586,15 +548,6 @@ ThemeView::ThemeView( void )
 	}
 	catch( ... ) { }
 
-	m_entry_name->signal_changed().connect(
-			sigc::mem_fun( this, &ThemeView::handle_name_changed ) );
-
-	m_entry_name->signal_activate().connect(
-			sigc::mem_fun( *m_button_name_apply, &Gtk::Button::clicked ) );
-
-	m_button_name_apply->signal_clicked().connect(
-			sigc::mem_fun( this, &ThemeView::handle_name_applied ) );
-
 	m_fontbutton->signal_font_set().connect(
 			sigc::mem_fun( *this, &ThemeView::handle_font_changed ) );
 	m_colorbutton_bground->signal_color_set().connect(
@@ -621,49 +574,54 @@ void
 ThemeView::show( Theme &theme )
 {
 	// do nothing is entry is already the current element:
-	if( ! Lifeobase::base->change_current_element( &theme, m_vbox ) )
+    if( Lifeobase::panel_main->is_cur_elem( &theme ) )
 		return;
 
 	m_ptr2theme = &theme;
 
-	// HEADER
-	Lifeobase::m_image_gui_elem->set( Lifeobase::icons->theme_32 );
-	Lifeobase::base->set_header_texts(
-			theme.get_name(), theme.is_system() ? _( "System theme" ) : _( "Custom theme" ) );
-	Lifeobase::set_gelem_toolbar( m_alignment_toolbar );
+	Lifeobase::panel_main->show( this );
 
 	// BODY
-	m_entry_name->set_text( theme.get_name() );
 	m_fontbutton->set_font_name( theme.font.to_string() );
-	m_colorbutton_bground->set_color( theme.color_base );
-	m_colorbutton_text->set_color( theme.color_text );
-	m_colorbutton_heading->set_color( theme.color_heading );
-	m_colorbutton_subheading->set_color( theme.color_subheading );
-	m_colorbutton_highlight->set_color( theme.color_highlight );
+	m_colorbutton_bground->set_rgba( theme.color_base );
+	m_colorbutton_text->set_rgba( theme.color_text );
+	m_colorbutton_heading->set_rgba( theme.color_heading );
+	m_colorbutton_subheading->set_rgba( theme.color_subheading );
+	m_colorbutton_highlight->set_rgba( theme.color_highlight );
 
 	update_preview();
-	m_vbox->set_sensitive( ! theme.is_system() );
-	m_button_dismiss->set_sensitive( ! theme.is_system() );
+	bool flag_sensitive = !( theme.is_system() || Diary::d->is_read_only() );
+	m_vbox->set_sensitive( flag_sensitive );
+	m_button_dismiss->set_sensitive( flag_sensitive );
 	m_button_make_default->set_visible( &theme != Diary::d->get_default_theme() );
 }
 
-void
-ThemeView::handle_name_changed( void )
+Glib::RefPtr< Gdk::Pixbuf >&
+ThemeView::get_icon_32( void ) const
 {
-	Glib::ustring name = m_entry_name->get_text();
-	PoolThemes::const_iterator iter = Diary::d->get_themes().find( name );
-	m_button_name_apply->set_sensitive( !( iter != Diary::d->get_themes().end() || name.empty() ) );
+    return Lifeobase::icons->theme_32;
 }
 
-void
-ThemeView::handle_name_applied( void )
+bool
+ThemeView::check_title_applicable( const Glib::ustring &name ) const
 {
-	Glib::ustring name = m_entry_name->get_text();
-	Diary::d->m_themes.rename_theme( m_ptr2theme, name );
-	Lifeobase::base->m_label_gui_elem->set_label( name );
-	Lifeobase::base->update_theme_list();
+    // system theme added back to m_themes:
+//    if( name == STRING::SYSTEM_THEME )
+//        return false;
+    PoolThemes::const_iterator iter = Diary::d->get_themes().find( name );
+	return( !( iter != Diary::d->get_themes().end() || name.empty() ) );
+}
 
-	m_button_name_apply->set_sensitive( false );
+bool
+ThemeView::apply_title( const Glib::ustring &name )
+{
+    if( ! check_title_applicable( name ) )
+        return false;
+
+    Diary::d->m_themes.rename_theme( m_ptr2theme, name );
+    Lifeobase::base->update_theme_list();
+
+    return true;
 }
 
 void
@@ -676,11 +634,11 @@ ThemeView::handle_font_changed( void )
 void
 ThemeView::handle_color_changed( void )
 {
-	m_ptr2theme->color_base = m_colorbutton_bground->get_color();
-	m_ptr2theme->color_text = m_colorbutton_text->get_color();
-	m_ptr2theme->color_heading = m_colorbutton_heading->get_color();
-	m_ptr2theme->color_subheading = m_colorbutton_subheading->get_color();
-	m_ptr2theme->color_highlight = m_colorbutton_highlight->get_color();
+	m_ptr2theme->color_base = m_colorbutton_bground->get_rgba();
+	m_ptr2theme->color_text = m_colorbutton_text->get_rgba();
+	m_ptr2theme->color_heading = m_colorbutton_heading->get_rgba();
+	m_ptr2theme->color_subheading = m_colorbutton_subheading->get_rgba();
+	m_ptr2theme->color_highlight = m_colorbutton_highlight->get_rgba();
 	update_preview();
 }
 
@@ -695,11 +653,13 @@ ThemeView::update_preview( void )
             convert_gdkcolor_to_html( m_ptr2theme->color_subheading ),
             convert_gdkcolor_to_html( m_ptr2theme->color_highlight ) ) );
     m_label_preview->set_markup( str_preview );
-    m_label_preview->modify_fg( Gtk::STATE_NORMAL, m_ptr2theme->color_text );
-    m_label_preview->modify_fg( Gtk::STATE_INSENSITIVE, m_ptr2theme->color_text );
-    m_eventbox_preview->modify_bg( Gtk::STATE_NORMAL, m_ptr2theme->color_base );
-    m_eventbox_preview->modify_bg( Gtk::STATE_INSENSITIVE, m_ptr2theme->color_base );
-    m_label_preview->modify_font( m_ptr2theme->font );
+    m_label_preview->override_color( m_ptr2theme->color_text, Gtk::STATE_FLAG_NORMAL );
+    m_label_preview->override_color( m_ptr2theme->color_text, Gtk::STATE_FLAG_INSENSITIVE );
+    m_eventbox_preview->override_background_color( m_ptr2theme->color_base,
+                                                   Gtk::STATE_FLAG_NORMAL );
+    m_eventbox_preview->override_background_color( m_ptr2theme->color_base,
+                                                   Gtk::STATE_FLAG_INSENSITIVE );
+    m_label_preview->override_font( m_ptr2theme->font );
 }
 
 // creating new themes is done by duplicating existing ones
@@ -709,6 +669,7 @@ ThemeView::duplicate( void )
 	Theme *new_theme = Diary::d->duplicate_theme( m_ptr2theme );
 	Lifeobase::base->update_theme_list();
 	new_theme->show();
+	Lifeobase::panel_main->start_title_edit();
 }
 
 void
@@ -727,7 +688,7 @@ ThemeView::dismiss_theme( void )
 
     Diary::d->show();
 
-	Lifeobase::base->remove_element_from_history( m_ptr2theme );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2theme );
 
 	Theme *theme = m_ptr2theme; // always be on the safe side
 	ThemeSystem::get()->show();
@@ -737,20 +698,24 @@ ThemeView::dismiss_theme( void )
 
 // DIARY ===========================================================================================
 DiaryView::DiaryView( void )
-:	m_vbox_diary( NULL ), m_dialog_password( NULL ), m_dialog_import( NULL ), m_dialog_export( NULL )
+:	m_dialog_password( NULL ), m_dialog_import( NULL ), m_dialog_export( NULL )
 {
 	Diary::shower = this;
 	m_ptr2diary = Diary::d;	// for now no other diary is shown in the view
 
 	Gtk::Button *button_import( NULL );
 	Gtk::Button *button_export( NULL );
-	Gtk::HBox   *hbox_chapter_ctg( NULL );
+    Gtk::Box    *hbox_chapter_ctg( NULL );
 	try
 	{
-		Lifeobase::builder->get_widget( "vbox_diary", m_vbox_diary );
-		Lifeobase::builder->get_widget( "alignment_diary_toolbar", m_alignment_toolbar );
+		Lifeobase::builder->get_widget( "vbox_diary", m_vbox );
+
+		Lifeobase::builder->get_widget( "frame_diary_startup", m_frame_startup );
+        Lifeobase::builder->get_widget( "frame_diary_chapters", m_frame_chapters );
+
 		Lifeobase::builder->get_widget( "label_path", m_label_path );
 		Lifeobase::builder->get_widget( "label_encryption", m_label_encryption );
+		Lifeobase::builder->get_widget( "button_password", m_button_password );
 
 		Lifeobase::builder->get_widget( "cmb_startup_type", m_combobox_startup_type );
 		Lifeobase::builder->get_widget( "label_startup_elem", m_label_startup_elem );
@@ -765,21 +730,18 @@ DiaryView::DiaryView( void )
 				m_button_chapter_ctg_dismiss );
 		Lifeobase::builder->get_widget( "button_chapter_ctg_rename",
 				m_button_chapter_ctg_rename );
+        Lifeobase::builder->get_widget( "combo_chapter_ctg", m_combobox_chapter_ctg );
 
         Lifeobase::builder->get_widget_derived( "drawingarea_diary_chart", m_widgetchart );
 
+		Lifeobase::builder->get_widget( "box_diary_toolbar", m_box_toolbar );
 		Lifeobase::builder->get_widget( "button_import", button_import );
 		Lifeobase::builder->get_widget( "button_export", button_export );
-		Lifeobase::builder->get_widget( "button_password", m_button_password );
-
 		Lifeobase::builder->get_widget( "button_log_out_wosaving",
 				m_button_logoutwosaving );
 
 		m_liststore_startup_type = Gtk::ListStore::create( colrec_startup_type );
 		m_liststore_chapter_ctg = Gtk::ListStore::create( colrec_chapter_ctg );
-
-		// temporary until we upgrade to gtkmm-3:
-		m_combobox_chapter_ctg = Gtk::manage( new Gtk::ComboBoxEntry );
 	}
 	catch( ... ) { }
 
@@ -799,11 +761,8 @@ DiaryView::DiaryView( void )
 	m_label_startup_elem_drop->drag_dest_set( Lifeobase::base->drag_targets_entry );
 
 	// CHAPTER CATEGORIES
-	hbox_chapter_ctg->pack_start( *m_combobox_chapter_ctg );
-	hbox_chapter_ctg->reorder_child( *m_combobox_chapter_ctg, 0 );
-	m_combobox_chapter_ctg->show();
 	m_combobox_chapter_ctg->set_model( m_liststore_chapter_ctg );
-	m_combobox_chapter_ctg->set_text_column( colrec_chapter_ctg.name );
+	m_combobox_chapter_ctg->set_entry_text_column( colrec_chapter_ctg.name );
 	m_combobox_chapter_ctg->set_row_separator_func(
 			sigc::mem_fun( this, &DiaryView::is_row_separator ) );
 
@@ -853,43 +812,23 @@ DiaryView::handle_login( void )
 		m_combobox_startup_type->set_active( 2 );
 
 	Lifeobase::m_internaloperation--;
+
+	m_button_password->set_sensitive( ! Diary::d->is_read_only() );
+    m_frame_startup->set_sensitive( ! Diary::d->is_read_only() );
+    m_frame_chapters->set_sensitive( ! Diary::d->is_read_only() );
 }
 
 void
 DiaryView::show( Diary &diary )
 {
 	// do nothing is entry is already the current element:
-	if( ! Lifeobase::base->change_current_element( &diary, m_vbox_diary ) )
+    if( Lifeobase::panel_main->is_cur_elem( &diary ) )
 		return;
 
 	// not necessary for now as there is only one diary to show in the view:
 	// m_ptr2diary = &diary;
 
-	// HEADER
-	int timespan( 0 );
-	if( ! diary.m_entries.empty() )
-	{
-		for( Entryiter iter = diary.m_entries.begin();
-			 iter != diary.m_entries.end();
-			 ++iter )
-		{
-			if( ! iter->second->get_date().is_ordinal() )
-			{
-				Glib::Date gdate_begin( diary.m_entries.rbegin()->second->get_date().get_glib() );
-				Glib::Date gdate_end( iter->second->get_date().get_glib() );
-				timespan = gdate_begin.days_between( gdate_end );
-				break;
-			}
-		}
-	}
-
-	Lifeobase::m_image_gui_elem->set( Lifeobase::icons->diary_32 );
-	Lifeobase::base->set_header_texts( diary.get_name(),
-									   Glib::ustring::compose(
-												_( "%1 entries spanning %2 days" ),
-												diary.m_entries.size(),
-												timespan ) );
-	Lifeobase::set_gelem_toolbar( m_alignment_toolbar );
+    Lifeobase::panel_main->show( this );
 
 	// BODY
 	m_button_password->set_label( diary.m_passphrase.empty() ? _( "Encrypt..." ) :
@@ -941,6 +880,12 @@ DiaryView::show( Diary &diary )
 #endif
 }
 
+Glib::RefPtr< Gdk::Pixbuf >&
+DiaryView::get_icon_32( void ) const
+{
+    return Lifeobase::icons->diary_32;
+}
+
 void
 DiaryView::start_dialog_password( void )
 {
@@ -986,8 +931,8 @@ DiaryView::start_dialog_import( void )
 
     if( response == RESPONSE_GO )
     {
-        Lifeobase::base->update_entry_list();
-        Lifeobase::base->update_tag_list();
+        Lifeobase::panel_diary->update_entry_list();
+        Lifeobase::panel_tag->populate_main();
         Lifeobase::base->update_theme_list();
     }
 }
@@ -1045,7 +990,7 @@ DiaryView::handle_startup_elem_dropped(
 	{
 		case DRAG_TARGET_ENTRY_INFO:
 		{
-			DiaryElement *element = Lifeobase::base->get_dragged_elem();
+			DiaryElement *element = Lifeobase::panel_diary->get_dragged_elem();
 			if( element != NULL )
 			{
 				m_label_startup_elem_drop->set_label( element->get_name() );
@@ -1119,7 +1064,7 @@ DiaryView::handle_cur_chapter_ctg_changed( void )
 
 	if( flag_renamed )
 	{
-		Glib::ustring name = m_combobox_chapter_ctg->get_active_text();
+		Glib::ustring name = m_combobox_chapter_ctg->get_entry_text();
 		bool flag_name_usable = m_ptr2diary->m_chapter_categories.count( name ) < 1;
 		m_button_chapter_ctg_rename->set_sensitive( flag_name_usable );
 	}
@@ -1136,7 +1081,7 @@ DiaryView::handle_cur_chapter_ctg_changed( void )
 			case CCCT_CATEGORY:
 				flag_existing_ctg = true;
 				m_ptr2diary->m_ptr2chapter_ctg_cur = row[ colrec_chapter_ctg.ptr ];
-				Lifeobase::base->update_entry_list();
+				Lifeobase::panel_diary->update_entry_list();
 				break;
 			default:	// for separators
 				break;
@@ -1152,7 +1097,7 @@ DiaryView::handle_cur_chapter_ctg_changed( void )
 void
 DiaryView::rename_cur_chapter_ctg( void )
 {
-	Glib::ustring name = m_combobox_chapter_ctg->get_active_text();
+	Glib::ustring name = m_combobox_chapter_ctg->get_entry_text();
 	if( name == m_ptr2diary->m_ptr2chapter_ctg_cur->get_name() )
 		return;
 	m_ptr2diary->rename_chapter_ctg( m_ptr2diary->m_ptr2chapter_ctg_cur, name );
