@@ -54,23 +54,37 @@ class TagView : public ElementShower< Tag >
 
 		void					show( Tag &tag );
 
+        DiaryElement*           get_element( void )
+        { return m_ptr2tag; }
+
+        Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon_32( void ) const;
+
+        Glib::ustring           get_title_str( void ) const
+        { return m_ptr2tag->m_name; }
+        Glib::ustring           get_info_str( void ) const
+        { return Glib::ustring::compose( _( "Tag with %1 entries" ), m_ptr2tag->get_size() ); }
+
+        bool                    is_title_editable( void ) const
+        { return true; }
+        Glib::ustring           get_title_edit_str( void ) const
+        { return m_ptr2tag->get_name(); }
+        bool                    check_title_applicable( const Glib::ustring& ) const;
+        bool                    apply_title( const Glib::ustring& );
+
+        void                    handle_login( void );
 		void					handle_filter_toggled( void );
-		void					handle_name_changed( void );
-		void					handle_name_applied( void );
 		void					handle_category_changed( void );
 		bool					is_row_separator( const Glib::RefPtr< Gtk::TreeModel >&,
 												  const Gtk::TreeIter );
 
 		void					update_combobox_categories( void );
+        void                    update_button_filter_tag( void );
 
 		void					dismiss_tag( void );
 
-		Gtk::VBox				*m_vbox;
-		Gtk::Alignment			*m_alignment_toolbar;
 		Gtk::ToggleButton		*m_button_filter;
 		Gtk::Button				*m_button_dismiss;
-		Gtk::Entry				*m_entry_name;
-		Gtk::Button				*m_button_name_apply;
 		Gtk::ComboBox			*m_combobox_category;
 		WidgetChart				*m_widgetchart;
 
@@ -102,15 +116,28 @@ class CategoryTagsView : public ElementShower< CategoryTags >
 
 		void					show( CategoryTags& );
 
+        DiaryElement*           get_element( void )
+        { return m_ptr2category; }
+
+        Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon_32( void ) const;
+
+        Glib::ustring           get_title_str( void ) const
+        { return m_ptr2category->m_name; }
+        Glib::ustring           get_info_str( void ) const
+        { return Glib::ustring::compose( _( "Tag category with %1 tags" ),
+                                         m_ptr2category->size() ); }
+
+        bool                    is_title_editable( void ) const
+        { return true; }
+        Glib::ustring           get_title_edit_str( void ) const
+        { return m_ptr2category->get_name(); }
+        bool                    check_title_applicable( const Glib::ustring& ) const;
+        bool                    apply_title( const Glib::ustring& );
+
 	protected:
-		void					handle_name_changed( void );
-		void					handle_name_applied( void );
 		void					dismiss_category( void );
 
-		Gtk::VBox				*m_vbox;
-		Gtk::Alignment			*m_alignment_toolbar;
-		Gtk::Entry				*m_entry_name;
-		Gtk::Button				*m_button_name_apply;
 		Gtk::Button				*m_button_dismiss;
 
 		CategoryTags			*m_ptr2category;
@@ -124,31 +151,60 @@ class ChapterView : public ElementShower< Chapter >
 
 		void					show( Chapter& );
 
+        DiaryElement*           get_element( void )
+        { return m_ptr2chapter; }
+
 	protected:
 		void					update_labels( void );
 		void					dismiss_chapter( void );
 
-		void					handle_name_changed( void );
-		void					handle_name_applied( void );
+        Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon_32( void ) const;
+
+        Glib::ustring           get_title_str( void ) const
+        {
+            if( m_ptr2chapter->m_date_begin.is_ordinal() )
+                return Glib::ustring::compose( "%1: %2",
+                                               m_ptr2chapter->m_date_begin.format_string(),
+                                               m_ptr2chapter->m_name );
+            else
+                return m_ptr2chapter->m_name;
+        }
+        Glib::ustring           get_info_str( void ) const
+        {
+            if( m_ptr2chapter->m_date_begin.is_ordinal() )
+                return Glib::ustring::compose( _( "Topic with %1 entries" ),
+                                               m_ptr2chapter->m_size );
+            else
+                return Glib::ustring::compose(
+                        m_ptr2chapter->m_time_span ?
+                                _( "Chapter with %1 entries in %2 days" ) :
+                                _( "Chapter with %1 entries" ),
+                        m_ptr2chapter->get_size(), m_ptr2chapter->m_time_span );
+        }
+
+        bool                    is_title_editable( void ) const
+        { return true; }
+        Glib::ustring           get_title_edit_str( void ) const
+        { return m_ptr2chapter->m_name; }
+		bool					check_title_applicable( const Glib::ustring& ) const;
+		bool					apply_title( const Glib::ustring& );
 
 		void					handle_date_changed( void );
 		void					handle_date_applied( void );
 
 		void					add_new_entry( void );
 
-		Gtk::VBox				*m_vbox;
-		Gtk::Alignment			*m_alignment_toolbar;
 		Gtk::Button				*m_button_dismiss;
-		Gtk::Entry				*m_entry_name;
-		Gtk::Button				*m_button_name_apply;
 
-		Gtk::Label				*m_label_period;
-		Gtk::HBox				*m_hbox_period;
+//		Gtk::Label				*m_label_period;
+//		Gtk::HBox				*m_hbox_period;
 		Gtk::Entry				*m_entry_begins;
 		Gtk::Button				*m_button_date_apply;
 		Gtk::Label				*m_label_ends;
 
-		Gtk::Frame				*m_frame_actions;
+		Gtk::Frame				*m_frame_edit;
+        Gtk::Frame              *m_frame_actions;
 
 		Chapter					*m_ptr2chapter;
 };
@@ -161,11 +217,25 @@ class ThemeView : public ElementShower< Theme >
 
 		void					show( Theme& );
 
+        DiaryElement*           get_element( void )
+        { return m_ptr2theme; }
+
+        Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon_32( void ) const;
+
+        Glib::ustring           get_title_str( void ) const
+        { return m_ptr2theme->get_name(); }
+        virtual Glib::ustring   get_info_str( void ) const
+        { return( m_ptr2theme->is_system() ? _( "System theme" ) : _( "Custom theme" ) ); }
+
+        bool                    is_title_editable( void ) const
+        { return true; }
+        Glib::ustring           get_title_edit_str( void ) const
+        { return m_ptr2theme->get_name(); }
+        bool                    check_title_applicable( const Glib::ustring& ) const;
+        bool                    apply_title( const Glib::ustring& );
+
 	protected:
-		Gtk::VBox				*m_vbox;
-		Gtk::Alignment			*m_alignment_toolbar;
-		Gtk::Entry				*m_entry_name;
-		Gtk::Button				*m_button_name_apply;
 		Gtk::FontButton			*m_fontbutton;
 		Gtk::ColorButton		*m_colorbutton_bground;
 		Gtk::ColorButton		*m_colorbutton_text;
@@ -181,8 +251,6 @@ class ThemeView : public ElementShower< Theme >
 
 		Theme					*m_ptr2theme;
 
-		void					handle_name_changed( void );
-		void					handle_name_applied( void );
 		void					handle_font_changed( void );
 		void					handle_color_changed( void );
 		void					update_preview( void );
@@ -203,6 +271,37 @@ class DiaryView : public ElementShower< Diary >
 
 		void					show( Diary& );
 
+		DiaryElement*           get_element( void )
+		{ return m_ptr2diary; }
+
+        Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon_32( void ) const;
+
+        Glib::ustring           get_list_str( void ) const
+        { return Glib::ustring::compose( "<b>%1</b>",
+                Glib::Markup::escape_text(
+                        Glib::filename_display_basename( m_ptr2diary->m_path ) ) ); }
+        Glib::ustring           get_title_str( void ) const
+        { return m_ptr2diary->m_name; }
+        Glib::ustring           get_info_str( void ) const
+        {
+            int timespan( 0 );
+            // FIXME: does not work for some obscure reason..
+            for( Entryciter iter_entry = m_ptr2diary->m_entries.begin();
+                    iter_entry != m_ptr2diary->m_entries.end();
+                    ++iter_entry )
+            {
+                if( ! iter_entry->second->get_date().is_ordinal() )
+                {
+                    timespan = m_ptr2diary->m_entries.rbegin()->second->get_date().
+                            calculate_days_between( iter_entry->second->get_date() );
+                    break;
+                }
+            }
+            return Glib::ustring::compose( _( "Diary with %1 entries spanning %2 days" ),
+                                           m_ptr2diary->m_entries.size(),
+                                           timespan );
+        }
 		// DIALOGS
 		void					start_dialog_password( void );
 		void					start_dialog_import( void );
@@ -225,8 +324,9 @@ class DiaryView : public ElementShower< Diary >
 		bool					is_row_separator( const Glib::RefPtr< Gtk::TreeModel >&,
 												  const Gtk::TreeIter );
 
-		Gtk::VBox				*m_vbox_diary;
-		Gtk::Alignment			*m_alignment_toolbar;
+        Gtk::Frame              *m_frame_startup;
+        Gtk::Frame              *m_frame_chapters;
+
 		Gtk::Label				*m_label_path;
 		Gtk::Label				*m_label_encryption;
 		Gtk::Button				*m_button_logoutwosaving;
@@ -253,7 +353,7 @@ class DiaryView : public ElementShower< Diary >
 		ColrecStartupType		colrec_startup_type;
 
 		// CHAPTER CATEGORIES & TOPICS
-		Gtk::ComboBoxEntry		*m_combobox_chapter_ctg;
+		Gtk::ComboBox           *m_combobox_chapter_ctg;
 		Gtk::Button				*m_button_chapter_ctg_dismiss;
 		Gtk::Button				*m_button_chapter_ctg_rename;
 
