@@ -33,6 +33,8 @@
 namespace LIFEO
 {
 
+using namespace HELPERS;
+
 class ChartPoint
 {
 	public:
@@ -85,7 +87,7 @@ class WidgetChart : public Gtk::DrawingArea
 		bool						on_button_release_event( GdkEventButton* );
 		bool						on_motion_notify_event( GdkEventMotion* );
 		bool						on_leave_notify_event( GdkEventCrossing* );
-		bool						on_expose_event( GdkEventExpose* );
+		bool						on_draw( const Cairo::RefPtr< Cairo::Context >& );
 
 		void						update_col_geom( bool = false );
 
