@@ -20,6 +20,7 @@
 ***********************************************************************************/
 
 
+#include "lifeobase.hpp"
 #include "widget_entrylist.hpp"
 #include "view_entry.hpp"
 
@@ -91,7 +92,7 @@ WidgetEntryList::expand_element( const DiaryElement *element )
 void
 WidgetEntryList::go_up( bool flag_entry_operation )
 {
-    DiaryElement *elem( Lifeobase::base->get_cur_elem() );
+    DiaryElement *elem( Lifeobase::panel_main->get_cur_elem() );
 
     if( elem == NULL )
         return;
@@ -131,7 +132,7 @@ WidgetEntryList::go_up( bool flag_entry_operation )
 void
 WidgetEntryList::go_down( bool flag_entry_operation )
 {
-    DiaryElement *elem( Lifeobase::base->get_cur_elem() );
+    DiaryElement *elem( Lifeobase::panel_main->get_cur_elem() );
 
     if( elem == NULL )
         return;
@@ -191,7 +192,7 @@ WidgetEntryList::handle_sorting_criteria_changed( SortingCriteria sc )
 			break;
 	}
 
-	Lifeobase::base->update_entry_list();
+	Lifeobase::panel_diary->update_entry_list();
 }
 
 void
@@ -341,15 +342,15 @@ WidgetEntryList::on_key_press_event( GdkEventKey *event )
     {
         switch( event->keyval )
         {
-            case GDK_Home:
+            case GDK_KEY_Home:
                 Diary::d->show();
                 return true;
-            case GDK_End:
+            case GDK_KEY_End:
                 return true;
-            case GDK_Up:
+            case GDK_KEY_Up:
                 go_up( false );
                 return true;
-            case GDK_Down:
+            case GDK_KEY_Down:
                 go_down( false );
                 return true;
         }
@@ -360,7 +361,7 @@ WidgetEntryList::on_key_press_event( GdkEventKey *event )
 void
 WidgetEntryList::on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& )
 {
-	m_flag_dragging = true;
+	m_flag_dragging = ! Diary::d->is_read_only();
 }
 
 void
@@ -482,7 +483,7 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext > &context,
 						chapter, m_element_drop_target->get_date() );
 			}
 
-			Lifeobase::base->update_entry_list();
+			Lifeobase::panel_diary->update_entry_list();
 			context->drag_finish( true, false, time );
 
 			return true;
