@@ -26,6 +26,7 @@
 
 #include <cmath>
 
+#include "lifeobase.hpp"
 #include "view_entry.hpp"
 #include "widget_textview.hpp"
 
@@ -38,10 +39,10 @@ Glib::RefPtr<Gtk::TextTag>      TextbufferDiary::m_tag_strikethrough;
 Glib::RefPtr<Gtk::TextTag>      TextbufferDiary::m_tag_highlight;
 Glib::RefPtr<Gtk::TextTag>      TextbufferDiary::m_tag_checkbox;
 
-Gdk::Color				TextbufferDiary::m_theme_color_match( "green" );
-Gdk::Color				TextbufferDiary::m_theme_color_markup( "gray" );
-Gdk::Color				TextbufferDiary::m_theme_color_link( "navy" );
-Gdk::Color				TextbufferDiary::m_theme_color_linkbroken( "red" );
+Gdk::RGBA                   TextbufferDiary::m_theme_color_match( "green" );
+Gdk::RGBA                   TextbufferDiary::m_theme_color_markup( "gray" );
+Gdk::RGBA                   TextbufferDiary::m_theme_color_link( "navy" );
+Gdk::RGBA                   TextbufferDiary::m_theme_color_linkbroken( "red" );
 
 Gtk::TextBuffer					*UndoEdit::m_ptr2buffer;
 
@@ -64,10 +65,7 @@ Link::~Link()
 	}
 }
 
-// LINK TO ENTRY
-// static variable:
-LinkEntry::Signal_void_Date LinkEntry::m_signal_activated;
-
+// LINK TO ID
 LinkID::LinkID( const Glib::RefPtr< Gtk::TextMark > &start,
 				const Glib::RefPtr< Gtk::TextMark > &end,
 				DEID id )
@@ -81,6 +79,8 @@ LinkID::go( void )
 	Diary::d->get_element( m_id )->show();
 }
 
+// LINK TO ENTRY
+Gtk::Menu *LinkEntry::menu_link = NULL;
 LinkEntry::LinkEntry( const Glib::RefPtr< Gtk::TextMark > &start,
 					  const Glib::RefPtr< Gtk::TextMark > &end,
 					  Date date )
@@ -91,7 +91,46 @@ LinkEntry::LinkEntry( const Glib::RefPtr< Gtk::TextMark > &start,
 void
 LinkEntry::go( void )
 {
-	m_signal_activated.emit( m_date );
+    Entryvector *entries = Diary::d->get_entries( m_date.get_pure() );
+
+    // seek and destroy cyclic links
+    for( Entryiterv iter = entries->begin(); iter != entries->end(); ++iter )
+    {
+        if( ( *iter ) == Lifeobase::panel_main->get_cur_elem() )
+        {
+            entries->erase( iter );
+            break;
+        }
+    }
+
+    if( entries->size() > 1 )
+    {
+        if( menu_link )
+            delete menu_link;
+        menu_link = new Gtk::Menu;
+
+        for( Entryiterv iter = entries->begin(); iter != entries->end(); ++iter )
+        {
+            Entry *entry = ( *iter );
+            Gtk::MenuItem *mitem = Gtk::manage( new Gtk::MenuItem( entry->get_name() ) );
+            mitem->signal_activate().connect(
+                    sigc::mem_fun( entry, &Entry::show ) );
+            menu_link->append( *mitem );
+        }
+        menu_link->show_all_children();
+        menu_link->popup( 0, gtk_get_current_event_time() );
+    }
+    else
+    if( entries->size() == 1 )
+        entries->at( 0 )->show();
+    else
+    {
+        Entry *entry = Diary::d->create_entry( m_date.m_date );
+        Lifeobase::panel_diary->update_entry_list();
+        entry->show();
+    }
+
+    delete entries;
 }
 
 // LINK TO URI
@@ -182,73 +221,76 @@ TextbufferDiary::TextbufferDiary( void )
 	m_tag_heading = Tag::create( "heading" );
 	m_tag_heading->property_weight() = Pango::WEIGHT_BOLD;
 	m_tag_heading->property_scale() = 1.5;
-	tag_table->add( m_tag_heading );
+	m_tags.push_back( m_tag_heading );
 
 	m_tag_subheading = Tag::create( "subheading" );
 	m_tag_subheading->property_weight() = Pango::WEIGHT_BOLD;
 	m_tag_subheading->property_scale() = 1.2;
-	tag_table->add( m_tag_subheading );
+	m_tags.push_back( m_tag_subheading );
 
 	m_tag_match = Tag::create( "match" );
-	tag_table->add( m_tag_match );
+	m_tags.push_back( m_tag_match );
 
 	m_tag_markup = Tag::create( "markup" );
 	m_tag_markup->property_scale() = 0.5;
-	tag_table->add( m_tag_markup );
+	m_tags.push_back( m_tag_markup );
 
 	m_tag_markup_link = Tag::create( "markup.link" );
-	tag_table->add( m_tag_markup_link );
+	m_tags.push_back( m_tag_markup_link );
 
 	m_tag_hidden = Tag::create( "hidden" );
 	m_tag_hidden->property_invisible() = true;
-	tag_table->add( m_tag_hidden );
+	m_tags.push_back( m_tag_hidden );
 
 	m_tag_bold = Tag::create( "bold" );
 	m_tag_bold->property_weight() = Pango::WEIGHT_BOLD;
-	tag_table->add( m_tag_bold );
+	m_tags.push_back( m_tag_bold );
 
 	m_tag_italic = Tag::create( "italic" );
 	m_tag_italic->property_style() = Pango::STYLE_ITALIC;
-	tag_table->add( m_tag_italic );
+	m_tags.push_back( m_tag_italic );
 
 	m_tag_strikethrough = Tag::create( "strikethrough" );
 	m_tag_strikethrough->property_strikethrough() = true;
-	tag_table->add( m_tag_strikethrough );
+	m_tags.push_back( m_tag_strikethrough );
 
 	m_tag_highlight = Tag::create( "highlight" );
-	tag_table->add( m_tag_highlight );
+	m_tags.push_back( m_tag_highlight );
 
     m_tag_comment = Tag::create( "comment" );
     m_tag_comment->property_scale() = 0.8;
     m_tag_comment->property_rise() = 5000;
-    tag_table->add( m_tag_comment );
+    m_tags.push_back( m_tag_comment );
 
     m_tag_region = Tag::create( "region" );
-    tag_table->add( m_tag_region );
+    m_tags.push_back( m_tag_region );
 
 	m_tag_link = Tag::create( "link" );
 	m_tag_link->property_underline() = Pango::UNDERLINE_SINGLE;
-	tag_table->add( m_tag_link );
+	m_tags.push_back( m_tag_link );
 
 	m_tag_link_broken = Tag::create( "link.broken" );
 	m_tag_link_broken->property_underline() = Pango::UNDERLINE_SINGLE;
-	tag_table->add( m_tag_link_broken );
+	m_tags.push_back( m_tag_link_broken );
 
 	// this is just for keeping the boundaries:
 	m_tag_link_hidden = Tag::create( "link.hidden" );
-	tag_table->add( m_tag_link_hidden );
+	m_tags.push_back( m_tag_link_hidden );
 
 	m_tag_checkbox = Tag::create( "checkbox" );
 	m_tag_checkbox->property_weight() = Pango::WEIGHT_BOLD;
 	m_tag_checkbox->property_scale() = 1.2;
-	tag_table->add( m_tag_checkbox );
+	m_tags.push_back( m_tag_checkbox );
+
+    for( VecTags::iterator iter_tag = m_tags.begin(); iter_tag != m_tags.end(); ++iter_tag )
+        tag_table->add( *iter_tag );
 }
 
 void
 TextbufferDiary::handle_login( void )
 {
 	// SPELL CHECKING
-	set_spellcheck( Diary::d->get_spellcheck() );
+	set_spellcheck( Diary::d->get_spellcheck() && ! Diary::d->is_read_only() );
 }
 
 void
@@ -342,8 +384,10 @@ TextbufferDiary::parse( unsigned int start, unsigned int end )
 	// BEGINNING & END
 	Gtk::TextIter   iter_start( get_iter_at_offset( start ) );
 	Gtk::TextIter	const iter_end( get_iter_at_offset( end ) );
-	// remove all tags:
-	remove_all_tags( iter_start, iter_end );
+	// remove all tags that belong to us:
+    for( VecTags::iterator iter_tag = m_tags.begin(); iter_tag != m_tags.end(); ++iter_tag )
+        remove_tag( *iter_tag, iter_start, iter_end );
+
 	clear_links( start, end );
 	EntryParser::parse( start, end );
 
@@ -370,7 +414,8 @@ TextbufferDiary::apply_heading( void )
 	{
 	    // TODO: can be improved:
 		m_ptr2entry->calculate_title( get_text() );
-		Lifeobase::base->handle_entry_title_changed( m_ptr2entry );
+		Lifeobase::panel_diary->handle_entry_title_changed( m_ptr2entry );
+		Lifeobase::panel_main->handle_title_changed_outside();
 	}
 }
 
@@ -513,48 +558,42 @@ TextbufferDiary::apply_link_id( void )
 void
 TextbufferDiary::apply_link_date( void )
 {
-    // FIXME: date should be ready before arriving here
-	date_last.set_day( int_last );
+    LinkStatus status( LS_OK );
+    Entry *ptr2entry( Diary::d->get_entry( date_last.m_date + 1 ) ); // + 1 fixes order
+    if( ptr2entry == NULL )
+        status = LS_ENTRY_UNAVAILABLE;
+    else
+    if( date_last.get_pure() == m_ptr2entry->get_date().get_pure() )
+        status = Diary::d->get_day_has_multiple_entries( date_last ) ? LS_OK : LS_CYCLIC;
 
-	if( date_last.is_valid() )
-	{
-		LinkStatus status( LS_OK );
-		Entry *ptr2entry( Diary::d->get_entry( date_last.m_date + 1 ) ); // + 1 fixes order
-		if( ptr2entry == NULL )
-			status = LS_ENTRY_UNAVAILABLE;
-		else
-		if( date_last.get_pure() == m_ptr2entry->get_date().get_pure() )
-			status = Diary::d->get_day_has_multiple_entries( date_last ) ? LS_OK : LS_CYCLIC;
+    Gtk::TextIter iter_start( get_iter_at_offset( pos_start ) );
+    Gtk::TextIter iter_current( get_iter_at_offset( pos_current ) );
+    Gtk::TextIter iter_tab( get_iter_at_offset( pos_tab ) );
 
-        Gtk::TextIter iter_start( get_iter_at_offset( pos_start ) );
-        Gtk::TextIter iter_current( get_iter_at_offset( pos_current ) );
-        Gtk::TextIter iter_tab( get_iter_at_offset( pos_tab ) );
-
-        if( status < LS_INVALID )
+    if( status < LS_INVALID )
+    {
+        Gtk::TextIter iter_end( iter_current );
+        iter_end++;
+        // if hidden link:
+        if( char_current == '>' )
         {
-            Gtk::TextIter iter_end( iter_current );
-            iter_end++;
-            // if hidden link:
-            if( char_current == '>' )
-            {
-                m_list_links.push_back( new LinkEntry( create_mark( iter_tab ),
-                                                       create_mark( iter_current ),
-                                                       date_last ) );
-                apply_hidden_link_tags( iter_end,
-                        status == LS_OK ? m_tag_link : m_tag_link_broken );
-			}
-			else
-			{
-				m_list_links.push_back(
-						new LinkEntry( create_mark( iter_start ),
-                                       create_mark( iter_end ),
-                                       date_last ) );
+            m_list_links.push_back( new LinkEntry( create_mark( iter_tab ),
+                                                   create_mark( iter_current ),
+                                                   date_last ) );
+            apply_hidden_link_tags( iter_end,
+                    status == LS_OK ? m_tag_link : m_tag_link_broken );
+        }
+        else
+        {
+            m_list_links.push_back(
+                    new LinkEntry( create_mark( iter_start ),
+                                   create_mark( iter_end ),
+                                   date_last ) );
 
-				apply_tag( status == LS_OK ? m_tag_link :
-								m_tag_link_broken, iter_start, iter_end );
-			}
-		}
-	}
+            apply_tag( status == LS_OK ? m_tag_link :
+                            m_tag_link_broken, iter_start, iter_end );
+        }
+    }
 }
 
 void
@@ -562,10 +601,11 @@ TextbufferDiary::apply_check_unf( void )
 {
     Gtk::TextIter iter_start( get_iter_at_offset( pos_current - 1 ) );
     Gtk::TextIter iter_end( get_iter_at_offset( pos_current ) );
-    m_list_links.push_back( new LinkCheck( create_mark( iter_start ),
-                                           create_mark( iter_end ),
-                                           0 ) );
-	apply_tag( m_tag_checkbox, iter_start, iter_end );
+    if( ! Diary::d->is_read_only() )
+        m_list_links.push_back( new LinkCheck( create_mark( iter_start ),
+                                               create_mark( iter_end ),
+                                               0 ) );
+    apply_tag( m_tag_checkbox, iter_start, iter_end );
 }
 
 void
@@ -575,9 +615,10 @@ TextbufferDiary::apply_check_fin( void )
     Gtk::TextIter iter_box( get_iter_at_offset( pos_current ) );
     Gtk::TextIter iter_end( iter_start );
     iter_end.forward_to_line_end();
-    m_list_links.push_back( new LinkCheck( create_mark( iter_start ),
-                                           create_mark( iter_box ),
-                                           1 ) );
+    if( ! Diary::d->is_read_only() )
+        m_list_links.push_back( new LinkCheck( create_mark( iter_start ),
+                                               create_mark( iter_box ),
+                                               1 ) );
     apply_tag( m_tag_checkbox, iter_start, iter_box );
     apply_tag( m_tag_highlight, iter_box, iter_end );
 }
@@ -589,9 +630,10 @@ TextbufferDiary::apply_check_ccl( void )
     Gtk::TextIter iter_box( get_iter_at_offset( pos_current ) );
     Gtk::TextIter iter_end( iter_start );
     iter_end.forward_to_line_end();
-    m_list_links.push_back( new LinkCheck( create_mark( iter_start ),
-                                           create_mark( iter_box ),
-                                           2 ) );
+    if( ! Diary::d->is_read_only() )
+        m_list_links.push_back( new LinkCheck( create_mark( iter_start ),
+                                               create_mark( iter_box ),
+                                               2 ) );
     apply_tag( m_tag_checkbox, iter_start, iter_box );
     apply_tag( m_tag_strikethrough, iter_box, iter_end );
 }
@@ -896,18 +938,6 @@ TextbufferDiary::on_apply_tag( const Glib::RefPtr< TextBuffer::Tag >& tag,
 		Gtk::TextBuffer::on_apply_tag( tag, iter_begin, iter_end );
 }
 
-void
-TextbufferDiary::on_remove_tag(	const Glib::RefPtr< TextBuffer::Tag >& tag,
-								const Gtk::TextIter& iter_begin,
-								const Gtk::TextIter& iter_end )
-{
-	// do not remove gtkspell tags while parsing:
-	if( m_flag_parsing && tag->property_name() == "gtkspell-misspelled" )
-		return;
-	else
-		Gtk::TextBuffer::on_remove_tag( tag, iter_begin, iter_end );
-}
-
 void
 TextbufferDiary::on_mark_set( const TextBuffer::iterator &iter,
 							  const Glib::RefPtr< TextBuffer::Mark > &mark )
@@ -1065,6 +1095,9 @@ TextbufferDiary::clear_links( void )
 void
 TextbufferDiary::handle_menu( Gtk::Menu *menu )
 {
+    if( Diary::d->is_read_only() )
+        return;
+
 	Gtk::CheckMenuItem *menuitem_spell = Gtk::manage(
 			new Gtk::CheckMenuItem( _( "Check Spelling" ) ) );
 
@@ -1279,22 +1312,53 @@ TextbufferDiary::handle_unindent( void )
 	erase( iter, iter_end );
 }
 
+class PredNL
+{
+  public:
+    bool operator()( gunichar ch ) const
+    {
+        return ch == '\n';
+    }
+};
+
 void
 TextbufferDiary::add_bullet( void )
 {
-	Gtk::TextIter iter = get_iter_at_mark( get_insert() );
-	if( iter.get_line() < 1 )	// no list in the first line
-		return;
-	const Glib::ustring::size_type	pos_cursor = iter.get_offset();
-	Glib::ustring::size_type		pos_list = get_text().rfind( '\n', pos_cursor - 1 );
-	if( pos_list == std::string::npos )
-		return;
-	++pos_list;	// get rid of the new line char
+    Gtk::TextIter iter( get_iter_at_mark( get_insert() ) );
+    Gtk::TextIter iter_end( iter );
+    bool flag_starts_first_para( false );
+    PredNL pnl;
 
-	iter = get_iter_at_offset( pos_list );
+    if( get_has_selection() )
+        get_selection_bounds( iter, iter_end );
+
+    if( ! iter.backward_find_char( pnl ) )
+    {
+        iter.forward_find_char( pnl );
+        flag_starts_first_para = true;
+    }
+    else
+        iter++;
+
+    if( iter_end.get_char() != '\n' )
+    {
+        if( ! iter_end.forward_find_char( pnl ) )
+        {
+            if( flag_starts_first_para )
+                return; // no list in the first line
+            iter_end.forward_to_end();
+        }
+    }
+    else if ( iter == iter_end ) // empty line
+    {
+        insert( iter, "\t• " );
+        return;
+    }
+
+    Glib::RefPtr< Gtk::TextMark > mark_end = create_mark( iter_end );
 	Gtk::TextIter iter_erase_begin( iter );
 	char char_lf( 't' );	// tab
-	while( true )
+	while( iter != get_iter_at_mark( mark_end ) )
 	{
 		switch( iter.get_char() )
 		{
@@ -1302,47 +1366,86 @@ TextbufferDiary::add_bullet( void )
 				if( char_lf == 'b' )
 					char_lf = 's';	// space
 				else
-					return;
+					char_lf = 'n'; // new line
 				break;
 			case ' ':
-				if( char_lf == 's' )
-					erase( iter_erase_begin, ++iter );
-				return;
+                if( char_lf == 's' || char_lf == 'S' )
+                {
+                    char_lf += ( 'g' - 's' ); // g or G depending on the previous value
+                    iter = erase( iter_erase_begin, ++iter );
+                    continue;
+                }
+                else
+                    break;
+			case '\n':
+			    char_lf = 't';  // tab
+			    break;
 			case L'☐':
 			case L'☑':
 			case L'☒':
-				// TODO: convert to bullet
-				return;
+                if( char_lf == 'b' )
+                    char_lf = 'S';  // capital s: space 2
+                else
+                    char_lf = 'n'; // new line
+                break;
 			case '\t':
-				char_lf = 'b';	// bullet
-				iter_erase_begin = iter;
-				break;
+                if( char_lf == 't'  || char_lf == 'b' )
+                {
+                    char_lf = 'b';  // bullet
+                    iter_erase_begin = iter;
+                }
+                break;
 			case 0:	// end
 			default:
-				if( char_lf != 's' )
-					insert( iter, "\t• " );
-				return;
+			    if( char_lf == 'G' || char_lf == 't' || char_lf == 'b' )
+					iter = insert( iter, "\t• " );
+			    char_lf = 'n';
+				break;
 		}
 		++iter;
 	}
+
+	delete_mark( mark_end );
 }
 
 void
 TextbufferDiary::add_checkbox( void )
 {
-	Gtk::TextIter iter( get_iter_at_mark( get_insert() ) );
-	if( iter.get_line() < 1 )	// no list in the first line
-		return;
-	const Glib::ustring::size_type	pos_cursor = iter.get_offset();
-	Glib::ustring::size_type		pos_list = get_text().rfind( '\n', pos_cursor - 1 );
-	if( pos_list == std::string::npos )
-		return;
-	++pos_list;	// get rid of the new line char
+    Gtk::TextIter iter( get_iter_at_mark( get_insert() ) );
+    Gtk::TextIter iter_end( iter );
+    bool flag_starts_first_para( false );
+    PredNL pnl;
 
-	iter = get_iter_at_offset( pos_list );
+    if( get_has_selection() )
+        get_selection_bounds( iter, iter_end );
+
+    if( ! iter.backward_find_char( pnl ) )
+    {
+        iter.forward_find_char( pnl );
+        flag_starts_first_para = true;
+    }
+    else
+        iter++;
+
+    if( iter_end.get_char() != '\n' )
+    {
+        if( ! iter_end.forward_find_char( pnl ) )
+        {
+            if( flag_starts_first_para )
+                return; // no list in the first line
+            iter_end.forward_to_end();
+        }
+    }
+    else if ( iter == iter_end ) // empty line
+    {
+        insert( iter, "\t☐ " );
+        return;
+    }
+
+    Glib::RefPtr< Gtk::TextMark > mark_end = create_mark( iter_end );
 	Gtk::TextIter iter_erase_begin( iter );
 	char char_lf( 't' );	// tab
-	while( true )
+	while( iter != get_iter_at_mark( mark_end ) )
 	{
 		switch( iter.get_char() )
 		{
@@ -1351,28 +1454,45 @@ TextbufferDiary::add_checkbox( void )
 			case L'☒':	// remove checkbox
 				if( char_lf == 'c' )
 					char_lf = 's';	// space
-				else
-					return;
-				break;
+                else
+                    char_lf = 'n'; // new line
+                break;
 			case ' ':
-				if( char_lf == 's' )
-					erase( iter_erase_begin, ++iter );
-				return;
+                if( char_lf == 's' || char_lf == 'S' )
+                {
+                    char_lf += ( 'g' - 's' ); // g or G depending on the previous value
+                    iter = erase( iter_erase_begin, ++iter );
+                    continue;
+                }
+                else
+                    break;
+            case '\n':
+                char_lf = 't';  // tab
+                break;
 			case L'•':
-				// TODO: convert to checkbox
-				return;
+                if( char_lf == 'c' )
+                    char_lf = 'S';  // capital s: space 2
+                else
+                    char_lf = 'n'; // new line
+                                    break;
 			case '\t':
-				char_lf = 'c';	// checkbox
-				iter_erase_begin = iter;
-				break;
+			    if( char_lf == 't'  || char_lf == 'c' )
+                {
+                    char_lf = 'c';  // bullet
+                    iter_erase_begin = iter;
+                }
+                break;
 			case 0:	// end
 			default:
-				if( char_lf != 's' )
-					insert( iter, "\t☐ " );
-				return;
+				if( char_lf == 'G' || char_lf == 't' || char_lf == 'c' )
+					iter = insert( iter, "\t☐ " );
+                char_lf = 'n';
+                break;
 		}
 		++iter;
 	}
+
+    delete_mark( mark_end );
 }
 
 void
@@ -1430,7 +1550,7 @@ TextbufferDiary::insert_time_stamp( void )
 		insert( get_iter_at_mark( get_insert() ), " ");
 
 	time_t date( time( NULL ) );
-	insert( get_iter_at_mark( get_insert() ), Date::format_string( &date ) );
+	insert( get_iter_at_mark( get_insert() ), Date::format_string( date ) );
 }
 
 void
@@ -1454,25 +1574,29 @@ TextbufferDiary::set_spellcheck( bool option_spell )
 void
 TextbufferDiary::set_theme( const Theme *theme )
 {
-	m_ptr2textview->modify_font( theme->font );
-	m_ptr2textview->modify_base( Gtk::STATE_NORMAL, theme->color_base );
-	m_ptr2textview->modify_text( Gtk::STATE_NORMAL, theme->color_text );
-	m_tag_heading->property_foreground_gdk() = theme->color_heading;
-	m_tag_subheading->property_foreground_gdk() = theme->color_subheading;
-	m_tag_highlight->property_background_gdk() = theme->color_highlight;
+	m_ptr2textview->override_font( theme->font );
+	m_ptr2textview->override_background_color( theme->color_base, Gtk::STATE_FLAG_NORMAL );
+	m_ptr2textview->override_color( theme->color_text, Gtk::STATE_FLAG_NORMAL );
 
-	Gdk::Color color_mid( midtone( theme->color_base, theme->color_text ) );
+    m_ptr2textview->override_background_color( theme->color_heading, Gtk::STATE_FLAG_SELECTED );
+    m_ptr2textview->override_color( theme->color_base, Gtk::STATE_FLAG_SELECTED );
 
-    m_tag_comment->property_foreground_gdk() = color_mid;
-    m_tag_region->property_paragraph_background_gdk() = midtone(
+	m_tag_heading->property_foreground_rgba() = theme->color_heading;
+	m_tag_subheading->property_foreground_rgba() = theme->color_subheading;
+	m_tag_highlight->property_background_rgba() = theme->color_highlight;
+
+	Gdk::RGBA color_mid( midtone( theme->color_base, theme->color_text ) );
+
+    m_tag_comment->property_foreground_rgba() = color_mid;
+    m_tag_region->property_paragraph_background_rgba() = midtone(
             theme->color_base, theme->color_text, 0.9 );
-	m_tag_match->property_background_gdk() = contrast(
+	m_tag_match->property_background_rgba() = contrast(
 			theme->color_base, m_theme_color_match );
-	m_tag_markup->property_foreground_gdk() = color_mid;
-	m_tag_markup_link->property_foreground_gdk() = color_mid;
-	m_tag_link->property_foreground_gdk() = contrast(
+	m_tag_markup->property_foreground_rgba() = color_mid;
+	m_tag_markup_link->property_foreground_rgba() = color_mid;
+	m_tag_link->property_foreground_rgba() = contrast(
 			theme->color_base, m_theme_color_link );
-	m_tag_link_broken->property_foreground_gdk() = contrast(
+	m_tag_link_broken->property_foreground_rgba() = contrast(
 			theme->color_base, m_theme_color_linkbroken );
 }
 
@@ -1482,7 +1606,8 @@ TextbufferDiary			*TextviewDiary::m_buffer;
 
 TextviewDiary::TextviewDiary( BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>& )
 :	Gtk::TextView( cobject ),
-	m_cursor_hand( Gdk::HAND2 ), m_cursor_xterm( Gdk::XTERM ),
+	m_cursor_hand( Gdk::Cursor::create( Gdk::HAND2 ) ),
+	m_cursor_xterm( Gdk::Cursor::create( Gdk::XTERM ) ),
 	m_ptr2cursor_last( &m_cursor_xterm ), m_link_hovered( NULL )
 {
 	set_buffer( static_cast< Glib::RefPtr< TextbufferDiary > >( m_buffer ) );
@@ -1498,7 +1623,8 @@ inline void
 TextviewDiary::update_link( void )
 {
 	Gtk::TextIter		iter;
-	const Gdk::Cursor	*ptr2cursor = &m_cursor_xterm;
+	const Glib::RefPtr< Gdk::Cursor >
+	                    *ptr2cursor = &m_cursor_xterm;
 	int					pointer_x, pointer_y;
 	int					trailing, buffer_x, buffer_y;
     Gdk::ModifierType	modifiers;
@@ -1551,7 +1677,8 @@ bool
 TextviewDiary::on_button_press_event( GdkEventButton *event )
 {
 	if( m_link_hovered != NULL )
-		if( ( event->state & Gdk::CONTROL_MASK ) != Gdk::CONTROL_MASK )
+		if( ( event->state & Gdk::CONTROL_MASK ) != Gdk::CONTROL_MASK &&
+	          event->button == 1 )
 			return true;
 
 	return Gtk::TextView::on_button_press_event( event );
@@ -1561,7 +1688,8 @@ bool
 TextviewDiary::on_button_release_event( GdkEventButton *event )
 {
 	if( m_link_hovered != NULL )
-		if( ( event->state & Gdk::CONTROL_MASK ) != Gdk::CONTROL_MASK )
+		if( ( event->state & Gdk::CONTROL_MASK ) != Gdk::CONTROL_MASK &&
+		      event->button == 1 )
 		{
 			m_link_hovered->go();
 			return true;
@@ -1573,82 +1701,85 @@ TextviewDiary::on_button_release_event( GdkEventButton *event )
 bool
 TextviewDiary::on_key_press_event( GdkEventKey *event )
 {
-	if( ( event->state & Gdk::CONTROL_MASK ) == Gdk::CONTROL_MASK )
-	{
-		switch( event->keyval )
-		{
-			case GDK_b:
-			case GDK_B:
-				m_buffer->toggle_bold();
-				break;
-			case GDK_i:
-			case GDK_I:
-				m_buffer->toggle_italic();
-				break;
-			case GDK_s:
-			case GDK_S:
-				m_buffer->toggle_strikethrough();
-				break;
-			case GDK_h:
-			case GDK_H:
-				m_buffer->toggle_highlight();
-				break;
-			case GDK_t:
-			case GDK_T:
-				Lifeobase::base->focus_tag();
-				break;
-		}
-	}
-	else
-	if( ( event->state & Gdk::MOD1_MASK )/* == Gdk::MOD1_MASK */)
-	{
-		PRINT_DEBUG( "mod1" );
-		switch( event->keyval )
-		{
-            case GDK_c:
-            case GDK_C:
-                Lifeobase::base->toggle_comments();
-                break;
-			case GDK_i:
-			case GDK_I:
-				m_buffer->handle_indent();
-				break;
-			case GDK_u:
-			case GDK_U:
-				m_buffer->handle_unindent();
-				break;
-			case GDK_l:
-			case GDK_L:
-				if( event->state & Gdk::SHIFT_MASK )
-					m_buffer->remove_empty_line_above();
-				else
-					m_buffer->add_empty_line_above();
-				break;
-			case GDK_t:
-			case GDK_T:
-				m_buffer->insert_time_stamp();
-				break;
-		}
-	}
-	else
-	if( event->state == 0 )
-	{
-		switch( event->keyval )
-		{
-			case GDK_space:
-				m_buffer->process_space();
-				break;
-			case GDK_Return:
-				if( m_buffer->process_new_line() )
-					return true;
-				break;
-			case GDK_Control_L:
-			case GDK_Control_R:
-				if( m_link_hovered )
-					update_link();
-				break;
-		}
-	}
+    if( ! Diary::d->is_read_only() )
+    {
+        if( ( event->state & Gdk::CONTROL_MASK ) == Gdk::CONTROL_MASK )
+        {
+            switch( event->keyval )
+            {
+                case GDK_KEY_b:
+                case GDK_KEY_B:
+                    m_buffer->toggle_bold();
+                    break;
+                case GDK_KEY_i:
+                case GDK_KEY_I:
+                    m_buffer->toggle_italic();
+                    break;
+                case GDK_KEY_s:
+                case GDK_KEY_S:
+                    m_buffer->toggle_strikethrough();
+                    break;
+                case GDK_KEY_h:
+                case GDK_KEY_H:
+                    m_buffer->toggle_highlight();
+                    break;
+                case GDK_KEY_t:
+                case GDK_KEY_T:
+                    Lifeobase::view_entry->focus_tag();
+                    break;
+            }
+        }
+        else
+        if( ( event->state & Gdk::MOD1_MASK )/* == Gdk::MOD1_MASK */)
+        {
+            PRINT_DEBUG( "mod1" );
+            switch( event->keyval )
+            {
+                case GDK_KEY_c:
+                case GDK_KEY_C:
+                    Lifeobase::view_entry->toggle_comments();
+                    break;
+                case GDK_KEY_i:
+                case GDK_KEY_I:
+                    m_buffer->handle_indent();
+                    break;
+                case GDK_KEY_u:
+                case GDK_KEY_U:
+                    m_buffer->handle_unindent();
+                    break;
+                case GDK_KEY_l:
+                case GDK_KEY_L:
+                    if( event->state & Gdk::SHIFT_MASK )
+                        m_buffer->remove_empty_line_above();
+                    else
+                        m_buffer->add_empty_line_above();
+                    break;
+                case GDK_KEY_t:
+                case GDK_KEY_T:
+                    m_buffer->insert_time_stamp();
+                    break;
+            }
+        }
+        else
+        if( event->state == 0 )
+        {
+            switch( event->keyval )
+            {
+                case GDK_KEY_space:
+                    m_buffer->process_space();
+                    break;
+                case GDK_KEY_Return:
+                    if( m_buffer->process_new_line() )
+                        return true;
+                    break;
+                case GDK_KEY_Control_L:
+                case GDK_KEY_Control_R:
+                    if( m_link_hovered )
+                        update_link();
+                    break;
+            }
+        }
+    }
 
 	return Gtk::TextView::on_key_press_event( event );
 }
@@ -1664,7 +1795,7 @@ TextviewDiary::on_key_press_event( GdkEventKey *event )
 bool
 TextviewDiary::on_key_release_event( GdkEventKey *event )
 {
-	if( event->keyval == GDK_Control_L || event->keyval == GDK_Control_R )
+	if( event->keyval == GDK_KEY_Control_L || event->keyval == GDK_KEY_Control_R )
 		if( m_link_hovered )
 			update_link();
 		
